<?php 
/* 
 ----------------------------------------------------------------------
 GLPI - Gestionnaire Libre de Parc Informatique
 Copyright (C) 2003-2010 by the INDEPNET Development Team.
 
 http://indepnet.net/   http://glpi-project.org
 ----------------------------------------------------------------------

 LICENSE

 This file is part of GLPI.

 GLPI is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.

 GLPI is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with GLPI; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 ------------------------------------------------------------------------
 */
//nl_NL

$LANG=array();


$LANG['backup'][0]="Dump SQL"; 
$LANG['backup'][1]="Dump XML"; 
$LANG['backup'][11]="Grootte"; 
$LANG['backup'][13]="Tonen/Downloaden"; 
$LANG['backup'][16]="Wilt u de huidige database overschrijven met dit bestand?"; 
$LANG['backup'][17]="Wilt u dit bestand verwijderen?"; 
$LANG['backup'][18]="Wilt u de database bewaren?"; 
$LANG['backup'][19]="Nu!"; 
$LANG['backup'][21]="Het bestand bestaat al"; 
$LANG['backup'][22]="Kan de byte NIET vinden"; 
$LANG['backup'][23]="Mysql fout begint vanaf"; 
$LANG['backup'][24]="Automatische omleiding, anders klikken"; 

$LANG['bookmark'][1]="Bladwijzer"; 
$LANG['bookmark'][2]="Partial load of the bookmark."; 
$LANG['bookmark'][3]="U heeft nu nog geen bladwijzer opgenomen."; 
$LANG['bookmark'][4]="Nieuwe bladwijzer"; 
$LANG['bookmark'][5]="Publieke bladwijzers"; 
$LANG['bookmark'][6]="Standaardvoorstelling"; 

$LANG['buttons'][0]="Zoeken"; 
$LANG['buttons'][2]="Verzenden"; 
$LANG['buttons'][3]="Toekennen"; 
$LANG['buttons'][4]="Installeren"; 
$LANG['buttons'][5]="De-installeren"; 
$LANG['buttons'][6]="Verwijderen"; 
$LANG['buttons'][7]="Updaten"; 
$LANG['buttons'][8]="Toevoegen"; 
$LANG['buttons'][9]="Verbinden"; 
$LANG['buttons'][10]="Verbinding verbreken"; 
$LANG['buttons'][11]="Volgende"; 
$LANG['buttons'][12]="Vorige"; 
$LANG['buttons'][13]="Terug"; 
$LANG['buttons'][14]="Wijzigen"; 
$LANG['buttons'][15]="Plan"; 
$LANG['buttons'][16]="Leeg"; 
$LANG['buttons'][17]="Selectie omkeren"; 
$LANG['buttons'][18]="Alles selecteren"; 
$LANG['buttons'][19]="Alles deselecteren"; 
$LANG['buttons'][20]="Verplaatsen"; 
$LANG['buttons'][21]="Herstellen"; 
$LANG['buttons'][22]="Zuiveren"; 
$LANG['buttons'][23]="Tonen"; 
$LANG['buttons'][24]="Naar boven"; 
$LANG['buttons'][25]="Naar beneden"; 
$LANG['buttons'][27]="PDF-export tonen"; 
$LANG['buttons'][28]="Pagina in SLK-export tonen"; 
$LANG['buttons'][29]="Export van alle pagina's in PDF"; 
$LANG['buttons'][30]="Export van alle pagina's in SLK"; 
$LANG['buttons'][31]="Exporteren"; 
$LANG['buttons'][32]="Einde"; 
$LANG['buttons'][33]="Start"; 
$LANG['buttons'][34]="Annuleren"; 
$LANG['buttons'][37]="Importeren"; 
$LANG['buttons'][38]="Deblokkeren"; 
$LANG['buttons'][39]="Vervang"; 
$LANG['buttons'][40]="Laat alles zien"; 
$LANG['buttons'][41]="Activeer"; 
$LANG['buttons'][42]="Deactiveren"; 
$LANG['buttons'][43]="Blader"; 
$LANG['buttons'][44]="Bekijk CSV export"; 
$LANG['buttons'][45]="Export van alle pagina's in CSV"; 
$LANG['buttons'][46]="Voor"; 
$LANG['buttons'][47]="Na"; 
$LANG['buttons'][48]="Verzenden"; 
$LANG['buttons'][49]="Bewaren"; 
$LANG['buttons'][50]="Test"; 
$LANG['buttons'][51]="Bewaren"; 
$LANG['buttons'][52]="Laden"; 
$LANG['buttons'][53]="Schoonmaken"; 
$LANG['buttons'][55]="Eerste"; 
$LANG['buttons'][56]="Laatste"; 
$LANG['buttons'][57]="Uitvoeren"; 
$LANG['buttons'][58]="Updaten"; 
$LANG['buttons'][59]="Relatie ontbinden"; 

$LANG['calendar'][0]="JJJJ-MM-DD (militair)"; 
$LANG['calendar'][1]="DD-MM-JJJJ"; 
$LANG['calendar'][2]="MM-DD-JJJJ (amerikaanse voorstelling)"; 

$LANG['calendarD'][0]="Z"; 
$LANG['calendarD'][1]="M"; 
$LANG['calendarD'][2]="D"; 
$LANG['calendarD'][3]="W"; 
$LANG['calendarD'][4]="D"; 
$LANG['calendarD'][5]="V"; 
$LANG['calendarD'][6]="Z"; 

$LANG['calendarDay'][0]="zondag"; 
$LANG['calendarDay'][1]="maandag"; 
$LANG['calendarDay'][2]="dinsdag"; 
$LANG['calendarDay'][3]="woensdag"; 
$LANG['calendarDay'][4]="donderdag"; 
$LANG['calendarDay'][5]="vrijdag"; 
$LANG['calendarDay'][6]="zaterdag"; 

$LANG['calendarM'][0]="januari"; 
$LANG['calendarM'][1]="februari"; 
$LANG['calendarM'][2]="maart"; 
$LANG['calendarM'][3]="april"; 
$LANG['calendarM'][4]="mei"; 
$LANG['calendarM'][5]="juni"; 
$LANG['calendarM'][6]="juli"; 
$LANG['calendarM'][7]="augustus"; 
$LANG['calendarM'][8]="september"; 
$LANG['calendarM'][9]="oktober"; 
$LANG['calendarM'][10]="november"; 
$LANG['calendarM'][11]="december"; 

$LANG['cartridges'][0]="Inktpatroon"; 
$LANG['cartridges'][7]="Geen inktpatroon gevonden"; 
$LANG['cartridges'][9]="Geen inktpatroon"; 
$LANG['cartridges'][10]="Toner"; 
$LANG['cartridges'][11]="Inktjet"; 
$LANG['cartridges'][12]="Inktpatroon type"; 
$LANG['cartridges'][13]="Nieuw"; 
$LANG['cartridges'][14]="Gebruikt"; 
$LANG['cartridges'][15]="Oud"; 
$LANG['cartridges'][16]="Inktpatronen"; 
$LANG['cartridges'][20]="Nieuw"; 
$LANG['cartridges'][21]="Gebruikt"; 
$LANG['cartridges'][22]="Oud"; 
$LANG['cartridges'][24]="Datum toevoegen"; 
$LANG['cartridges'][27]="Aan"; 
$LANG['cartridges'][29]="Einde levensduur"; 
$LANG['cartridges'][32]="Type van compatibele printers"; 
$LANG['cartridges'][33]="Gebruikte inktpatronen"; 
$LANG['cartridges'][34]="Geen vrij inktpatroon"; 
$LANG['cartridges'][35]="Gebruikte inktpatronen"; 
$LANG['cartridges'][37]="Lint"; 
$LANG['cartridges'][39]="Printerteller"; 
$LANG['cartridges'][40]="Gemiddelde tijd in magazijn"; 
$LANG['cartridges'][41]="Gemiddelde tijd in gebruik"; 
$LANG['cartridges'][42]="Gemiddeld aantal geprinte pagina's"; 

$LANG['central'][2]="Laatst"; 
$LANG['central'][4]="Geen gebeurtenis"; 
$LANG['central'][5]="Home"; 
$LANG['central'][6]="Uitloggen"; 
$LANG['central'][7]="Help"; 
$LANG['central'][8]="Toevoegingen"; 
$LANG['central'][9]="Uw huidige tussenkomsten"; 
$LANG['central'][10]="Geen toegewezen tussenkomsten"; 
$LANG['central'][12]="Persoonlijk Overzicht"; 
$LANG['central'][13]="Globaal overzicht"; 
$LANG['central'][14]="Groepsoverzicht"; 
$LANG['central'][18]="Uw af te sluiten Incident-tickets"; 
$LANG['central'][19]="Uw Incident-tickets ter validatie"; 

$LANG['choice'][0]="Nee"; 
$LANG['choice'][1]="Ja"; 

$LANG['common'][0]="Zonder naam"; 
$LANG['common'][1]="Item"; 
$LANG['common'][2]="ID"; 
$LANG['common'][3]="Belijk de prullenmand"; 
$LANG['common'][4]="web"; 
$LANG['common'][5]="Fabrikant"; 
$LANG['common'][6]="Sjabloonnaam"; 
$LANG['common'][7]="Sjabloon kiezen"; 
$LANG['common'][8]="Sjablonen beheren ..."; 
$LANG['common'][9]="Sjabloon toevoegen ..."; 
$LANG['common'][10]="Technisch verantwoordelijke"; 
$LANG['common'][11]="Beperkte voorstelling"; 
$LANG['common'][12]="Setup"; 
$LANG['common'][13]="Sjabloon"; 
$LANG['common'][14]="Sjablonen"; 
$LANG['common'][15]="Locatie"; 
$LANG['common'][16]="Naam"; 
$LANG['common'][17]="Type"; 
$LANG['common'][18]="Alternatieve gebruikersnaam"; 
$LANG['common'][19]="Reeksnummer"; 
$LANG['common'][20]="Inventarisnummer"; 
$LANG['common'][21]="Alternatieve gebruikersnaam nummer"; 
$LANG['common'][22]="Model"; 
$LANG['common'][23]="Operatie geslaagd"; 
$LANG['common'][24]="Geen onderdeel geselecteerd of niet goed bepaalde operatie"; 
$LANG['common'][25]="Commentaren"; 
$LANG['common'][26]="Laatste update"; 
$LANG['common'][27]="Datum"; 
$LANG['common'][28]="Verwijderd"; 
$LANG['common'][29]="Plugins"; 
$LANG['common'][30]="Nieuw Item"; 
$LANG['common'][31]="Lege Template"; 
$LANG['common'][32]="Karakteristieken"; 
$LANG['common'][33]="Totaal"; 
$LANG['common'][34]="Gebruiker"; 
$LANG['common'][35]="Groep"; 
$LANG['common'][36]="Categorie"; 
$LANG['common'][37]="Auteur"; 
$LANG['common'][38]="Gebruik eenheidsmanagement"; 
$LANG['common'][39]="Kopieer het onderdeel, net zo vaak als er verbindingen zijn"; 
$LANG['common'][40]="Weet u het zeker dat u eenheidmanagement wilt uitzetten voor dit item ?"; 
$LANG['common'][41]="E-mail Alarm(en)"; 
$LANG['common'][42]="GSM (mobiel toestel)"; 
$LANG['common'][43]="Voornaam"; 
$LANG['common'][44]="Standaard waarde"; 
$LANG['common'][45]="MB max"; 
$LANG['common'][46]="Vcard"; 
$LANG['common'][47]="Voortgang"; 
$LANG['common'][48]="Achternaam"; 
$LANG['common'][49]="Geen"; 
$LANG['common'][50]="Bevestig de vewijdering?"; 
$LANG['common'][51]="Gehele Naam"; 
$LANG['common'][52]="Server"; 
$LANG['common'][53]="Lijst"; 
$LANG['common'][54]="Item niet gevonden"; 
$LANG['common'][55]="Weet u het zeker dat u dit onderdeel wilt verwijderen?"; 
$LANG['common'][56]="Standaard interface"; 
$LANG['common'][57]="Titel"; 
$LANG['common'][58]="Maximum waarde"; 
$LANG['common'][59]="Allesomvattend"; 
$LANG['common'][60]="Actief"; 
$LANG['common'][61]="Onbekende fout"; 
$LANG['common'][62]="Andere"; 
$LANG['common'][63]="Fout(en)"; 
$LANG['common'][64]="Manager"; 
$LANG['common'][65]="Interface"; 
$LANG['common'][66]="Allemaal"; 
$LANG['common'][67]="Andere"; 
$LANG['common'][68]="Landscape"; 
$LANG['common'][69]="Portrait"; 
$LANG['common'][70]="Item succesvol toegevoegd"; 
$LANG['common'][71]="Item succesvol bijgewerkt"; 
$LANG['common'][72]="Item succesvol verwijderd"; 
$LANG['common'][73]="Item succesvol definitief verwijderd"; 
$LANG['common'][74]="Item succesvol hersteld"; 
$LANG['common'][75]="Geen rechten om deze item recursief te maken in deze entiteit."; 
$LANG['common'][76]="Publiek"; 
$LANG['common'][77]="Prive"; 
$LANG['common'][78]="Instellen als publiek"; 
$LANG['common'][79]="Instellen als persoonlijk"; 
$LANG['common'][80]="Tijdens laden..."; 
$LANG['common'][81]="Recupereren (undelete)"; 
$LANG['common'][82]="Mb"; 
$LANG['common'][83]="U heeft niet de bevoegdheid voor het uitvoeren van deze actie."; 
$LANG['common'][84]="De aanwezigheid van verbonden items, verhindert de wijziging van deze status (attribuut)"; 
$LANG['common'][85]="Verander zichtbaarheid van de sub-entiteiten"; 
$LANG['common'][86]="U bent niet gemachtigd voor het aanpassen van de zichtbaarheid van deze sub-entiteiten."; 
$LANG['common'][87]="Nieuwe kaart"; 
$LANG['common'][88]="Personeel"; 
$LANG['common'][89]="Niet geïnstalleerd"; 
$LANG['common'][90]="Object"; 
$LANG['common'][91]="Dit item is afhankelijk van (een of meer) andere. Het wijzigen van deze status (attribuut) is niet toegelaten"; 
$LANG['common'][92]="Contact"; 
$LANG['common'][93]="Nieuwe sub-hoofding"; 

$LANG['computers'][0]="Volume"; 
$LANG['computers'][1]="Vrij percentage"; 
$LANG['computers'][2]="Vrije ruimte"; 
$LANG['computers'][3]="Globale omvang"; 
$LANG['computers'][4]="Bestandssysteem"; 
$LANG['computers'][5]="Mount point"; 
$LANG['computers'][6]="Partitie"; 
$LANG['computers'][7]="Voeg een volume toe"; 
$LANG['computers'][8]="Volumes"; 
$LANG['computers'][9]="Besturingssysteem"; 
$LANG['computers'][10]="Serienummer operating system"; 
$LANG['computers'][11]="Operating System produkt ID"; 
$LANG['computers'][14]="Tussengevoegd"; 
$LANG['computers'][23]="RAM-type"; 
$LANG['computers'][24]="RAM (MB)"; 
$LANG['computers'][25]="HD grootte (in GB)"; 
$LANG['computers'][36]="HDD-type"; 
$LANG['computers'][37]="Geen aangesloten beeldscherm"; 
$LANG['computers'][38]="Geen aangesloten printer"; 
$LANG['computers'][39]="Printers"; 
$LANG['computers'][40]="Beeldschermen"; 
$LANG['computers'][46]="Toestellen"; 
$LANG['computers'][47]="Geen aangesloten toestellen"; 
$LANG['computers'][48]="Update van de locatie.  De gelinkte items werden naar dezelfde locatie verplaatst."; 
$LANG['computers'][49]="Update van alternatieve gebruikersnaam.  De gelinkte items werden hiermee aangepast."; 
$LANG['computers'][50]="Gebruiker of groep geupdate. De items die waren verbonden zijn verhuisd naar dezelfde waardes."; 
$LANG['computers'][51]="Bron updaten"; 
$LANG['computers'][52]="OS-versie"; 
$LANG['computers'][53]="Servicepack"; 
$LANG['computers'][54]="Geen telefoon aangesloten"; 
$LANG['computers'][55]="Telefoon(s)"; 
$LANG['computers'][56]="Status ge-update. De verbonden items zijn bijgewerkt met deze status."; 

$LANG['connect'][0]="Directe verbindingen"; 
$LANG['connect'][1]="niet verbonden"; 
$LANG['connect'][15]="Automatische update van de volgende items"; 
$LANG['connect'][16]="Waarschuwing!! De volgende items van de 2 hardware items zijn niet gelijk."; 

$LANG['consumables'][0]="Verbruiksartikel"; 
$LANG['consumables'][1]="In voorraad"; 
$LANG['consumables'][2]="Referentie"; 
$LANG['consumables'][7]="Geen verbruiksartikelen gevonden"; 
$LANG['consumables'][9]="Geen verbruiksartikel"; 
$LANG['consumables'][12]="Verbruiksartikeltype"; 
$LANG['consumables'][13]="Nieuw"; 
$LANG['consumables'][15]="Gebruikt"; 
$LANG['consumables'][16]="Verbruiksartikel(en)"; 
$LANG['consumables'][20]="Nieuw"; 
$LANG['consumables'][22]="Gebruikt"; 
$LANG['consumables'][23]="Staat"; 
$LANG['consumables'][26]="Gebruiksdatum"; 
$LANG['consumables'][32]="Geef"; 
$LANG['consumables'][35]="Gebruikte verbruiksartikelen"; 
$LANG['consumables'][36]="Magazijnlocatie"; 
$LANG['consumables'][37]="Terug naar magazijn"; 
$LANG['consumables'][38]="Alarmdrempel"; 

$LANG['contract'][0]="Vervallen contract sinds"; 
$LANG['contract'][1]="Contract opgezegd sinds"; 

$LANG['crontask'][0]="Automatische acties"; 
$LANG['crontask'][1]="Synchronistaie van toestellen vanuit OCSNG"; 
$LANG['crontask'][2]="Stuur alarm over cartridges"; 
$LANG['crontask'][3]="Stuur alarm over verbruiksartikelen"; 
$LANG['crontask'][4]="Stuur alarm over vervallen licenties"; 
$LANG['crontask'][5]="Stuur alarm over contracten"; 
$LANG['crontask'][6]="Stuur alalrm over financiële informatie"; 
$LANG['crontask'][7]="Oude logfiles verwijderen"; 
$LANG['crontask'][8]="Optimaliseren van de database"; 
$LANG['crontask'][9]="Recuperatie van berichten (ontvangers)"; 
$LANG['crontask'][10]="Controle van de MySQL replica"; 
$LANG['crontask'][11]="Controle van de aanwezigheid van de updates"; 
$LANG['crontask'][12]="Vervallen sessies verwijderen"; 
$LANG['crontask'][13]="Gegenereerde grafieken verwijderen"; 
$LANG['crontask'][14]="Automatisch aflsuiten van de Incident-tickets"; 
$LANG['crontask'][15]="Niet opgeloste Incident-tickets"; 
$LANG['crontask'][31]="Gestopt"; 
$LANG['crontask'][32]="Geprogrammeerd"; 
$LANG['crontask'][33]="Bezig (wordt nu uitgevoerd)"; 
$LANG['crontask'][34]="GLPI"; 
$LANG['crontask'][35]="Command line interface"; 
$LANG['crontask'][36]="Uitvoeringswijze"; 
$LANG['crontask'][37]="Uitvoeringsfrequentie"; 
$LANG['crontask'][38]="Urenoverzicht uitvoering"; 
$LANG['crontask'][39]="Aantal emails op te halen"; 
$LANG['crontask'][40]="Laatste uitvoering"; 
$LANG['crontask'][41]="Volgende uitvoering"; 
$LANG['crontask'][42]="ASAP"; 
$LANG['crontask'][43]="Geen activiteit in de wachtlijst"; 
$LANG['crontask'][44]="Actie voltooid, verwerking gedeeltelijk afgewerkt"; 
$LANG['crontask'][45]="Actie voltooid, verwerking volledig afgewerkt"; 
$LANG['crontask'][46]="Actie voltooid, niets te doen"; 
$LANG['crontask'][47]="Lijst van de laatste uitvoeringen"; 
$LANG['crontask'][48]="Start"; 
$LANG['crontask'][50]="Aantal uitvoeringen"; 
$LANG['crontask'][51]="Minimum duur"; 
$LANG['crontask'][52]="Maximum duur"; 
$LANG['crontask'][53]="Gemiddelde duur"; 
$LANG['crontask'][55]="Minimum aantal"; 
$LANG['crontask'][56]="Maximum aantal"; 
$LANG['crontask'][57]="Gemiddeld aantal"; 
$LANG['crontask'][58]="Totaal aantal"; 
$LANG['crontask'][59]="Gemiddelde snelheid"; 
$LANG['crontask'][60]="Systeemslot"; 
$LANG['crontask'][61]="Plugin gedesactiveerd"; 
$LANG['crontask'][62]="Elementen"; 

$LANG['devices'][0]="Een nieuw intern toestel toevoegen"; 
$LANG['devices'][1]="Harde schijf"; 
$LANG['devices'][2]="Grafische kaart"; 
$LANG['devices'][3]="Netwerkinterface"; 
$LANG['devices'][4]="CPU"; 
$LANG['devices'][5]="Moederbord"; 
$LANG['devices'][6]="RAM"; 
$LANG['devices'][7]="Geluidskaart"; 
$LANG['devices'][19]="Drives"; 
$LANG['devices'][20]="Controllers"; 
$LANG['devices'][21]="Andere randapparatuur"; 
$LANG['devices'][22]="Cases"; 
$LANG['devices'][23]="Voeding"; 
$LANG['devices'][24]="standaard"; 
$LANG['devices'][25]="Voeg een interne component toe"; 
$LANG['devices'][26]="Een intern toestel verwijderen"; 

$LANG['device_case'][0]="Grootte"; 

$LANG['device_control'][0]="RAID"; 

$LANG['device_drive'][0]="Schrijven"; 
$LANG['device_drive'][1]="Snelheid"; 

$LANG['device_hdd'][0]="Tpm."; 
$LANG['device_hdd'][1]="Cache (MB)"; 
$LANG['device_hdd'][4]="Capaciteit"; 

$LANG['device_iface'][0]="Flow"; 
$LANG['device_iface'][2]="MAC-adres"; 

$LANG['device_moboard'][0]="Chipset"; 

$LANG['device_power'][0]="Voeding"; 
$LANG['device_power'][1]="ATX"; 

$LANG['device_ram'][1]="Bussnelheid"; 
$LANG['device_ram'][2]="Grootte"; 

$LANG['document'][1]="Checksum (SHA1)"; 
$LANG['document'][2]="Bestand"; 
$LANG['document'][3]="Rubriek"; 
$LANG['document'][4]="MIME type"; 
$LANG['document'][7]="Documenttype"; 
$LANG['document'][9]="Bestandstype"; 
$LANG['document'][10]="Icoon"; 
$LANG['document'][11]="Toegestane download"; 
$LANG['document'][15]="Downloaden"; 
$LANG['document'][16]="Document toevoegen"; 
$LANG['document'][18]="Document"; 
$LANG['document'][19]="Geassocieerde items"; 
$LANG['document'][21]="Geassocieerde documenten"; 
$LANG['document'][22]="Huidig bestand"; 
$LANG['document'][23]="Bestand is te groot om toe te voegen."; 
$LANG['document'][24]="Het verwijderen van het bestand is gelukt"; 
$LANG['document'][25]="Het verwijderen van het bestand is mislukt"; 
$LANG['document'][26]="Het uploaden is gelukt"; 
$LANG['document'][27]="Mogelijke upload-aanval, of bestand te groot"; 
$LANG['document'][28]="Geen bestandsnaam opgegeven."; 
$LANG['document'][29]="Map aanmaken niet gelukt"; 
$LANG['document'][30]="Controleer of je de juiste rechten hebt."; 
$LANG['document'][31]="Map voor documenten bestaat niet"; 
$LANG['document'][32]="Niet toegestaan bestandstype"; 
$LANG['document'][33]="Weblink"; 
$LANG['document'][34]="Map aanmaken"; 
$LANG['document'][35]="Map voor het uploaden bestaat niet."; 
$LANG['document'][36]="Een FTP-installed bestand gebruiken"; 
$LANG['document'][37]="Geen bestand beschikbaar"; 
$LANG['document'][38]="Bestand niet gevonden"; 
$LANG['document'][39]="Document verplaatsen gelukt"; 
$LANG['document'][40]="Document verplaatsen mislukt"; 
$LANG['document'][41]="Document kopiëren gelukt"; 
$LANG['document'][42]="Toegevoegd door"; 
$LANG['document'][43]="Onbekend bestand"; 
$LANG['document'][44]="Verkeerde bestandsnaam"; 
$LANG['document'][45]="U bent niet geautoriseerd voor toegang van deze file"; 
$LANG['document'][46]="Fout bij het versturen van het bestand (waarschijnlijk te groot)"; 
$LANG['document'][48]="Een document met dat bestand is reeds beschikbaar"; 
$LANG['document'][49]="Bestand gewijzigd (verkeerde checksum)"; 
$LANG['document'][50]="Verbonden elementen"; 

$LANG['entity'][0]="Entiteit"; 
$LANG['entity'][2]="Root entiteit"; 
$LANG['entity'][3]="Vebinden met een entiteit"; 
$LANG['entity'][5]="Automatische toekenning van de computer(s)"; 
$LANG['entity'][6]="Automatische toekenning gebruiker(s)"; 
$LANG['entity'][7]="boom struktuur"; 
$LANG['entity'][8]="Per entiteit"; 
$LANG['entity'][9]="Sub-entiteiten"; 
$LANG['entity'][10]="Selecteer de gewenste entiteit"; 
$LANG['entity'][11]="om de entiteit en zijn sub-entiteiten te bekijken"; 
$LANG['entity'][12]="Entiteit (LDAP informatie over de Entiteit)"; 
$LANG['entity'][13]="Entiteit : TAG"; 
$LANG['entity'][14]="Gevorderde informatie"; 
$LANG['entity'][15]="Entiteit-Directory"; 
$LANG['entity'][16]="Zoekfilter (indien nodig)"; 
$LANG['entity'][17]="Configureren van de automatische afsluiting"; 
$LANG['entity'][18]="Automatisch afsluiten van opgeloste Incidenten-tickets na (termijn)"; 

$LANG['event'][0]="Bron"; 
$LANG['event'][2]="Dienst"; 
$LANG['event'][3]="Niveau"; 
$LANG['event'][4]="Bericht"; 
$LANG['event'][18]="Veld"; 
$LANG['event'][19]="Update"; 
$LANG['event'][20]="Geen geschiedenis"; 

$LANG['financial'][1]="Contract"; 
$LANG['financial'][2]="Voor altijd"; 
$LANG['financial'][3]="Financiële informatie"; 
$LANG['financial'][4]="Nummer"; 
$LANG['financial'][5]="Kostprijs"; 
$LANG['financial'][6]="Contracttype"; 
$LANG['financial'][8]="Duur"; 
$LANG['financial'][9]="jaar(jaren)"; 
$LANG['financial'][10]="Opzegging"; 
$LANG['financial'][11]="Factuur Periode"; 
$LANG['financial'][13]="Boekhoudnummer"; 
$LANG['financial'][14]="Aankoopdatum"; 
$LANG['financial'][15]="Garantieperiode"; 
$LANG['financial'][16]="Garantie-informatie"; 
$LANG['financial'][18]="Bestelnr."; 
$LANG['financial'][19]="Afleveringsdocument"; 
$LANG['financial'][20]="Immobilisatienummer"; 
$LANG['financial'][21]="Waarde"; 
$LANG['financial'][22]="Afschrijvingstype"; 
$LANG['financial'][23]="Afschrijvingsperiode"; 
$LANG['financial'][24]="Contactpersoon toevoegen ..."; 
$LANG['financial'][25]="Leverancier toevoegen ..."; 
$LANG['financial'][26]="Leverancier"; 
$LANG['financial'][30]="Fax"; 
$LANG['financial'][33]="Contactpersoon toevoegen"; 
$LANG['financial'][36]="Contract toevoegen"; 
$LANG['financial'][42]="Commercieel"; 
$LANG['financial'][43]="Technicus"; 
$LANG['financial'][44]="Adres"; 
$LANG['financial'][45]="Website"; 
$LANG['financial'][46]="Verbonden contactpersonen"; 
$LANG['financial'][47]="Lineair"; 
$LANG['financial'][48]="Degressief"; 
$LANG['financial'][50]="Lening"; 
$LANG['financial'][51]="Huren"; 
$LANG['financial'][52]="Leasing"; 
$LANG['financial'][53]="Verzekeringen"; 
$LANG['financial'][54]="Hardware-onderhoud"; 
$LANG['financial'][55]="Software-onderhoud"; 
$LANG['financial'][56]="Prestatie"; 
$LANG['financial'][57]="maand"; 
$LANG['financial'][59]="Uren tussenkomst"; 
$LANG['financial'][60]="gedurende de week"; 
$LANG['financial'][61]="op zaterdag"; 
$LANG['financial'][62]="zon- en feestdagen"; 
$LANG['financial'][65]="Verbonden leveranciers"; 
$LANG['financial'][66]="Verbonden contract(en)"; 
$LANG['financial'][68]="Activeer de financiële informatie"; 
$LANG['financial'][69]="Contract Periode"; 
$LANG['financial'][76]="Opstartdatum"; 
$LANG['financial'][77]="Afschrijvingscoëfficiënt"; 
$LANG['financial'][78]="Garantiewaarde bij verlenging"; 
$LANG['financial'][79]="Derdepartijtype"; 
$LANG['financial'][80]="Vervaldatum garantieperiode"; 
$LANG['financial'][81]="Netto boekwaarde"; 
$LANG['financial'][82]="Factuurnr."; 
$LANG['financial'][83]="Max. aantal items (0 = oneindig)"; 
$LANG['financial'][84]="Voor dit type element is de financiële informatie slechts een model voor de gelijkaardige elementen die je later toevoegt."; 
$LANG['financial'][85]="Gevraagde item niet gevonden"; 
$LANG['financial'][86]="Vervaldatum contract"; 
$LANG['financial'][87]="Budget"; 
$LANG['financial'][88]="Vervalt op:"; 
$LANG['financial'][89]="TCO (aanschafwaarde + kosten van onderhoud en herstellingen)"; 
$LANG['financial'][90]="Maandelijkse TCO"; 
$LANG['financial'][91]="TCO"; 
$LANG['financial'][92]="Netto Boekwaarde"; 
$LANG['financial'][93]="Vervallen Contracten - sinds de laatste 30 dagen"; 
$LANG['financial'][94]="Contracten die zullen vervallen binnen 7 dagen"; 
$LANG['financial'][95]="Contracten die zullen vervallen binnen 30 dagen"; 
$LANG['financial'][96]="Contract(en) waarvoor de ingediende opzeggingstermijn in minder dan 7 dagen aanvangt"; 
$LANG['financial'][97]="Contract(en) waarvoor de ingediende opzeggingstermijn in minder dan 30 dagen aanvangt"; 
$LANG['financial'][98]="Vervaldatum"; 
$LANG['financial'][99]="Vervaldatum + Opzeggingstermijn"; 
$LANG['financial'][100]="Postcode"; 
$LANG['financial'][101]="Woonplaats"; 
$LANG['financial'][102]="Status (staat bvb 'nieuw')"; 
$LANG['financial'][103]="Land"; 
$LANG['financial'][104]="Verbonden items"; 
$LANG['financial'][105]="Stilzwijgend"; 
$LANG['financial'][106]="Uitdrukkelijk (schriftelijk te bevestigen)"; 
$LANG['financial'][107]="Verlenging"; 
$LANG['financial'][108]="Totaal uitgegeven voor het budget"; 
$LANG['financial'][109]="Overblijvend totaal van het budget"; 
$LANG['financial'][110]="Budgetten"; 

$LANG['gmt'][0]="GMT"; 
$LANG['gmt'][1]="uur(uren)"; 
$LANG['gmt'][2]="u"; 

$LANG['help'][1]="Prioriteitenmatrix"; 
$LANG['help'][2]="Hoogste"; 
$LANG['help'][3]="Zeer hoog"; 
$LANG['help'][4]="Hoog"; 
$LANG['help'][5]="Gemiddeld"; 
$LANG['help'][6]="Laag"; 
$LANG['help'][7]="Zeer laag"; 
$LANG['help'][8]="Informeer me over de genomen acties"; 
$LANG['help'][11]="Mijn e-mail"; 
$LANG['help'][14]="Een bericht verzenden"; 
$LANG['help'][16]="Indien u op de hoogte  wilt worden gehouden over de oplossing van uw probleem, vul dan uw e-mailadres in."; 
$LANG['help'][18]="Uw aanvraag werd succesvol geregistreerd, en wordt verder verwerkt."; 
$LANG['help'][19]="Dank U voor het gebruik van ons automatisch Incident meldingssysteem"; 
$LANG['help'][22]="Zoek het Identificatienummer van uw computer"; 
$LANG['help'][23]="Geef de eerste letters (gebruikersnaam,item of serienr.)"; 
$LANG['help'][24]="Dit Incident-ticket gaat over"; 
$LANG['help'][25]="Computer"; 
$LANG['help'][26]="Netwerkapparaat"; 
$LANG['help'][27]="Printer"; 
$LANG['help'][28]="Scherm"; 
$LANG['help'][29]="Randapparatuur"; 
$LANG['help'][30]="Algemeen"; 
$LANG['help'][31]="Software"; 
$LANG['help'][35]="Telefoon"; 
$LANG['help'][40]="De titel van uw ticket ontbreekt, probeer het opnieuw."; 
$LANG['help'][41]="Het Incident-ticket werd niet aan een categorie toegewezen, geef opnieuw een categorie."; 
$LANG['help'][42]="Zeer hoog"; 
$LANG['help'][43]="Hoog"; 
$LANG['help'][44]="Gemiddeld"; 
$LANG['help'][45]="Laag"; 
$LANG['help'][46]="Zeer laag"; 
$LANG['help'][47]="Zeer hoog"; 
$LANG['help'][48]="Hoog"; 
$LANG['help'][49]="Gemiddeld"; 
$LANG['help'][50]="Laag"; 
$LANG['help'][51]="Zeer laag"; 

$LANG['install'][0]="Installeer of update GLPI"; 
$LANG['install'][1]="Kies 'Installeren' voor een nieuwe complete installatie van GLPI."; 
$LANG['install'][2]="Kies 'Update' voor een update van GLPI vanaf een oudere versie"; 
$LANG['install'][3]="Installeer"; 
$LANG['install'][4]="Update"; 
$LANG['install'][5]="Compatibiliteitscontrole van het systeem waar GLPI draait"; 
$LANG['install'][6]="Test voltooid"; 
$LANG['install'][7]="Resultaten"; 
$LANG['install'][8]="Test PHP Parser"; 
$LANG['install'][9]="U moet PHP5 installeren.  Hier kunt u het downloaden:"; 
$LANG['install'][10]="GLPI is niet compatibel met de optie zend.ze1_compatibility_mode = On."; 
$LANG['install'][11]="PHP versie is 5.x - Perfect!"; 
$LANG['install'][12]="Sessietest"; 
$LANG['install'][13]="Uw PHP-parser is niet gecompileerd met ondersteuning voor sessies!"; 
$LANG['install'][14]="Ondersteuning voor de sessies is beschikbaar - Perfect!"; 
$LANG['install'][15]="Controleer of de ondersteuning van de sessies goed is ingesteld in uw php.ini"; 
$LANG['install'][16]="Controleer schrijfrechten voor dumpbestanden"; 
$LANG['install'][17]="Het bestand kon niet aangemaakt worden"; 
$LANG['install'][18]="Niet officiële vertalingen zijn ook beschikbaar"; 
$LANG['install'][19]="Het bestand werd aangemaakt, maar kan niet verwijderd worden"; 
$LANG['install'][20]="Een bestand en directorie zijn aangemaakt en daarna verwijderd - Perfect!"; 
$LANG['install'][21]="Controleer schrijfrechten voor documenten"; 
$LANG['install'][22]="Een file is aangemaakt - Perfect !"; 
$LANG['install'][23]="Check writing mode for setting diles"; 
$LANG['install'][24]="Initialisatie van de database"; 
$LANG['install'][25]="Verder?"; 
$LANG['install'][26]="Verder"; 
$LANG['install'][27]="Probeer opnieuw"; 
$LANG['install'][28]="Setup van de databankverbinding"; 
$LANG['install'][29]="Parameters voor de databankverbinding"; 
$LANG['install'][30]="Mysql server"; 
$LANG['install'][31]="Mysql-gebruiker"; 
$LANG['install'][32]="Mysql wachtwoord"; 
$LANG['install'][34]="Test van de verbinding met de databank"; 
$LANG['install'][35]="Onmogelijk een verbinding te maken met de databank"; 
$LANG['install'][36]="De server antwoordde"; 
$LANG['install'][37]="Server- en/of gebruikersveld is leeg"; 
$LANG['install'][38]="Selecteer een databank:"; 
$LANG['install'][39]="Maak een nieuwe of gebruik een bestaande databank:"; 
$LANG['install'][40]="Selecteer de databank die bijgewerkt moet worden:"; 
$LANG['install'][41]="Onmogelijk om de databank te gebruiken:"; 
$LANG['install'][43]="OK - databank is geïnitialiseerd"; 
$LANG['install'][47]="Onmogelijk om te schrijven naar het databank-set-upbestand"; 
$LANG['install'][48]="Fout bij aanmaken databank!"; 
$LANG['install'][49]="Er werd geen databank geselecteerd!"; 
$LANG['install'][50]="Controle schrijf rechten voor sessie bestanden"; 
$LANG['install'][52]="Controle van het bewaren van cron bestanden"; 
$LANG['install'][53]="Test met het schrijven van log bestanden"; 
$LANG['install'][55]="De installatie is voltooid"; 
$LANG['install'][57]="Standaard gebruikersnaam/wachtwoord zijn:"; 
$LANG['install'][58]="GLPI/GLPI voor de admin-gebruiker"; 
$LANG['install'][59]="tech/tech voor de technische gebruiker"; 
$LANG['install'][60]="normal/normal voor het normal account"; 
$LANG['install'][61]="post-only/post-only voor het 'alleen posten'-gebruikersaccount"; 
$LANG['install'][62]="U kunt deze gebruikers verwijderen of wijzigen, net als de intiële waarden in de databank"; 
$LANG['install'][64]="Gebruik GLPI"; 
$LANG['install'][65]="Test op de uitbreiding 'Magic_Quotes_Sybase'"; 
$LANG['install'][66]="GLPI kan niet werken met de 'Magic_Quotes_Sybase'-optie.  Deactiveer de optie en probeer opnieuw."; 
$LANG['install'][67]="De 'Magic_Quotes_Sybase'-optie is niet actief op de server - Perfect!"; 
$LANG['install'][68]="Test sessie-autostart"; 
$LANG['install'][69]="session.auto_start geactiveerd. Bekijk het bestand .htaccess in rootdirectory van GLPI voor meer informatie."; 
$LANG['install'][70]="Onmogelijk om het databank verbindingsbestand aan te maken.  Controleer de rechten van de bestanden."; 
$LANG['install'][71]="MySQL-uitbreidingstest"; 
$LANG['install'][72]="Compileer uw PHP met de MySQL-uitbreiding"; 
$LANG['install'][73]="OK - de funtie 'MySQL_connect()' bestaat - Perfect!"; 
$LANG['install'][74]="Test of 'Session_Use_Trans_Sid' wordt gebruikt"; 
$LANG['install'][75]="De optie 'session_Use_Trans_Id' moet uitgeschakeld zijn in uw php.ini"; 
$LANG['install'][76]="OK - de sessie werkt (geen probleem met trans_id) - Perfect!"; 
$LANG['install'][77]="Step"; 
$LANG['install'][81]="Start van de installatie"; 
$LANG['install'][82]="Databank aangemaakt"; 
$LANG['install'][85]="De functies werden gevonden - Perfect!"; 
$LANG['install'][86]="Test van voorbehouden geheugen"; 
$LANG['install'][87]="Voorbehouden geheugen:"; 
$LANG['install'][88]="Een minimum van 64Mb is gewoonlijk vereist voor GLPI"; 
$LANG['install'][89]="Perfect!"; 
$LANG['install'][90]="Probeer de geheugenlimietparameter te verhogen in het php.ini-bestand"; 
$LANG['install'][91]="Voorbehouden geheugen > 64M"; 
$LANG['install'][92]="Licentie"; 
$LANG['install'][93]="Ik heb de licentievoorwaarden hierboven gelezen en AANVAARD deze"; 
$LANG['install'][94]="Ik heb de licentievoorwaarden hierboven gelezen en AANVAARD deze NIET"; 
$LANG['install'][95]="Onbegrensd geheugen"; 
$LANG['install'][96]="Onbegrensd geheugen"; 
$LANG['install'][97]="Controleer of PHP schrijfrechten heeft in de directorie:"; 
$LANG['install'][99]="Controle schrijf rechten voor cache bestanden"; 
$LANG['install'][100]="De directorie kan niet worden aangemaakt"; 
$LANG['install'][101]="De directorie is aangemaakt maar kon NIET worden verwijderd."; 
$LANG['install'][102]="Test json functies"; 
$LANG['install'][103]="GLPI kan niet correct werken zonder de json_encode en json_decode functies"; 
$LANG['install'][104]="mbstring extentie test"; 
$LANG['install'][105]="Mbstring extensie van de PHP parser is niet geinstalleerd"; 
$LANG['install'][106]="Test grafische bestanden opslaan"; 

$LANG['job'][2]="door"; 
$LANG['job'][4]="Aanvrager"; 
$LANG['job'][5]="Toegekend aan"; 
$LANG['job'][6]="Technicien"; 
$LANG['job'][7]="Taak"; 
$LANG['job'][8]="laatste ticket(s)"; 
$LANG['job'][9]="Opvolging"; 
$LANG['job'][11]="Beschrijf het probleem/actie"; 
$LANG['job'][12]="Geen opvolgingen voor deze tussenkomst"; 
$LANG['job'][13]="Nieuw ticket toevoegen"; 
$LANG['job'][15]="Opgelost"; 
$LANG['job'][19]="E-mailopvolgingen"; 
$LANG['job'][20]="Reële tijd van de tussenkomst"; 
$LANG['job'][21]="uren"; 
$LANG['job'][22]="minuten"; 
$LANG['job'][29]="Nieuwe opvolging toevoegen"; 
$LANG['job'][30]="Een nieuwe taak toevoegen"; 
$LANG['job'][31]="Duur"; 
$LANG['job'][32]="Geen"; 
$LANG['job'][33]="Lege beschrijving"; 
$LANG['job'][34]="Deze taak plannen"; 
$LANG['job'][35]="Planning"; 
$LANG['job'][37]="Samenvatting"; 
$LANG['job'][38]="Ticket"; 
$LANG['job'][39]="Opvolging bijwerken"; 
$LANG['job'][40]="Tijdkost"; 
$LANG['job'][41]="Vaste kost"; 
$LANG['job'][42]="Materiële kost"; 
$LANG['job'][43]="Totale kost"; 
$LANG['job'][44]="Aangevraagde bron"; 
$LANG['job'][45]="Bron van de opvolging"; 
$LANG['job'][46]="Ticket toegeveogd aan de entiteit"; 
$LANG['job'][47]="Kosten"; 
$LANG['job'][48]="Type oplossing"; 
$LANG['job'][49]="Nieuwe taak"; 
$LANG['job'][50]="Geen taak voor dit ticket"; 
$LANG['job'][51]="Goedkeuring van de oplossing"; 
$LANG['job'][52]="Update van een taak"; 
$LANG['job'][53]="Taak verwijderen"; 
$LANG['job'][54]="Zonder antwoord van uwentwege zal het ticket automatisch worden afgesloten"; 

$LANG['joblist'][0]="Status"; 
$LANG['joblist'][1]="Alleen die van mijzelf"; 
$LANG['joblist'][2]="Prioriteit"; 
$LANG['joblist'][3]="Persoonlijk + groep(en)"; 
$LANG['joblist'][4]="Toegewezen"; 
$LANG['joblist'][6]="Beschrijving"; 
$LANG['joblist'][7]="Nieuwe taak voor dit item ..."; 
$LANG['joblist'][8]="Geen tussenkomst gevonden"; 
$LANG['joblist'][9]="Nieuw"; 
$LANG['joblist'][10]="Oud"; 
$LANG['joblist'][11]="Geopend op"; 
$LANG['joblist'][12]="Afgesloten op"; 
$LANG['joblist'][13]="Te verwerken Incident-tickets"; 
$LANG['joblist'][14]="Opgelost op"; 
$LANG['joblist'][16]="Geen tussenkomst in werking"; 
$LANG['joblist'][17]="Afgesloten (niet opgelost)"; 
$LANG['joblist'][18]="Bezig met verwerken (toegewezen)"; 
$LANG['joblist'][19]="Bezig met verwerken (gepland)"; 
$LANG['joblist'][21]="Bezig met verwerken"; 
$LANG['joblist'][26]="Wachten"; 
$LANG['joblist'][27]="E-mail om na te trekken"; 
$LANG['joblist'][28]="Incident-tickets met betrekking tot verwante elementen"; 
$LANG['joblist'][29]="Urgentie"; 
$LANG['joblist'][30]="Impact"; 
$LANG['joblist'][32]="Opgelost"; 
$LANG['joblist'][33]="Afgesloten"; 
$LANG['joblist'][34]="Niet opgelost"; 
$LANG['joblist'][35]="Niet gesloten"; 
$LANG['joblist'][36]="Status basiswaarde"; 

$LANG['jobresolution'][1]="Oplossing"; 
$LANG['jobresolution'][3]="Oplossing goedgekeurd"; 
$LANG['jobresolution'][4]="Oplossing afgekeurd"; 
$LANG['jobresolution'][5]="Indien de oplossing niet wordt goedgekeurd, geef een motivering"; 

$LANG['knowbase'][1]="FAQ"; 
$LANG['knowbase'][5]="Item toevoegen aan de publieke FAQ"; 
$LANG['knowbase'][6]="Selecteer een categorie voor dit item:"; 
$LANG['knowbase'][7]="Verwijder dit item van de publieke FAQ"; 
$LANG['knowbase'][8]="Wijzig dit item"; 
$LANG['knowbase'][9]="Verwijder dit item"; 
$LANG['knowbase'][10]="Dit item hoort tot de publieke FAQ"; 
$LANG['knowbase'][11]="Dit item hoort niet tot de publieke FAQ"; 
$LANG['knowbase'][12]="Root"; 
$LANG['knowbase'][13]="Categorienaam"; 
$LANG['knowbase'][14]="Onderwerp"; 
$LANG['knowbase'][15]="Inhoud"; 
$LANG['knowbase'][24]="Toegang tot de FAQ"; 
$LANG['knowbase'][26]="Overzicht(en)"; 
$LANG['knowbase'][27]="Op"; 
$LANG['knowbase'][29]="Recentelijk toegevoegd"; 
$LANG['knowbase'][30]="Meest populaire vragen"; 

$LANG['ldap'][0]="Grote import van gebruikers uit een LDAP directory"; 
$LANG['ldap'][1]="Synchronisatie van de al geïmporteerde gebruikers"; 
$LANG['ldap'][2]="Importeer nieuwe gebruikers"; 
$LANG['ldap'][3]="Geen gebruikers te importeren"; 
$LANG['ldap'][4]="LDAP directorie keuze"; 
$LANG['ldap'][5]="Kies a.u.b. een LDAP directorie om de gebruikers van te importeren"; 
$LANG['ldap'][6]="Kan geen verbinding maken met de LDAP directorie"; 
$LANG['ldap'][7]="Geen LDAP directorie ingesteld in GLPI"; 
$LANG['ldap'][8]="Waarschuwing: Het verzoek overschrijdt de limiet van het directory, enkel partiële resultaten zijn beschikbaar"; 
$LANG['ldap'][9]="Test om een verbinding met de LDAP directorie te krijgen"; 
$LANG['ldap'][12]="Synchronisatie"; 
$LANG['ldap'][13]="in de LDAP directory"; 
$LANG['ldap'][14]="in GLPI"; 
$LANG['ldap'][15]="Synchronisatie"; 
$LANG['ldap'][16]="Voorconfiguratie"; 
$LANG['ldap'][17]="Active Directory"; 
$LANG['ldap'][18]="Lijst van LDAP-directory replicas"; 
$LANG['ldap'][19]="Repliceer"; 
$LANG['ldap'][20]="Een replica van de LDAP-directory toegevoegen"; 
$LANG['ldap'][21]="Hoofd server"; 
$LANG['ldap'][22]="Replicatie(s)"; 
$LANG['ldap'][23]="Importeer groepen vanuit een LDAP directory (bulk)"; 
$LANG['ldap'][24]="Importeren van nieuwe groepen"; 
$LANG['ldap'][25]="Er zijn geen groepen geïmporteerd"; 
$LANG['ldap'][30]="Hoe LDAP aliases gebruikt moeten worden"; 
$LANG['ldap'][31]="Nooit dereferenced (standaard)"; 
$LANG['ldap'][32]="Altijd dereferenced"; 
$LANG['ldap'][33]="Dereferenced bij het zoeken (niet bij het localiseren)"; 
$LANG['ldap'][34]="Dereferenced bij het localiseren (niet bij het zoeken)"; 
$LANG['ldap'][35]="Importeer en gebruiker"; 
$LANG['ldap'][36]="Er is geen directory verbonden met de entiteit : zoeken is onmogelijk"; 
$LANG['ldap'][38]="Zoekcriteria voor gebruikers"; 
$LANG['ldap'][39]="Gevorderd"; 
$LANG['ldap'][40]="Eenvoudig"; 
$LANG['ldap'][41]="Wijzig"; 
$LANG['ldap'][42]="Geen directory geselecteerd"; 
$LANG['ldap'][43]="Geen gebruikers te synchroniseren"; 
$LANG['ldap'][44]="Default server"; 
$LANG['ldap'][45]="Actie wanneer een gebruiker werd verwijderd uit het LDAP directory"; 
$LANG['ldap'][46]="Trek accreditaties en groupen in (dynamisch)"; 
$LANG['ldap'][47]="Verwijderen"; 
$LANG['ldap'][48]="Gebruiker verwijderd uit de LDAP directory"; 
$LANG['ldap'][49]="Bekijk toegevoegde gebruikers sinds"; 
$LANG['ldap'][50]="Bekijk de gebruikers gewijzigd sinds"; 
$LANG['ldap'][52]="minder dan"; 
$LANG['ldap'][53]="meer dan"; 
$LANG['ldap'][54]="Activeer filtering per datum"; 
$LANG['ldap'][55]="Filtering op datum afzetten"; 
$LANG['ldap'][56]="Weken"; 

$LANG['links'][1]="Link"; 
$LANG['links'][4]="Geassocieerde hardwaretype"; 
$LANG['links'][6]="Geldige TAGS"; 
$LANG['links'][7]="Geen link aanwezig"; 
$LANG['links'][9]="Bestandsinhoud"; 

$LANG['log'][1]="systeem"; 
$LANG['log'][16]="planning"; 
$LANG['log'][18]="apparaten"; 
$LANG['log'][20]="item toegevoegd"; 
$LANG['log'][21]="item bijwerken"; 
$LANG['log'][22]="item verwijderen"; 
$LANG['log'][23]="item herstellen"; 
$LANG['log'][24]="item zuiveren"; 
$LANG['log'][26]="item loskoppelen"; 
$LANG['log'][27]="itemverbinding"; 
$LANG['log'][28]="wijziging van componenten"; 
$LANG['log'][29]="goedkeuring/weigering van een oplossing"; 
$LANG['log'][30]="Associeer een type"; 
$LANG['log'][31]="een type verwijderen"; 
$LANG['log'][32]="een link aan het item toevoegen"; 
$LANG['log'][33]="de link met het item verwijderen"; 
$LANG['log'][34]="een link met de leverancier toevoegen"; 
$LANG['log'][35]="de link met de leverancier verwijderen"; 
$LANG['log'][40]="IP-verbinding"; 
$LANG['log'][41]="verbinding mislukt"; 
$LANG['log'][42]="boeking"; 
$LANG['log'][44]="Rubriek"; 
$LANG['log'][45]="Geslaagd"; 
$LANG['log'][46]="Mislukt"; 
$LANG['log'][48]="Gebruiker aan groep toevoegen"; 
$LANG['log'][49]="verwijder gebruiker van groep"; 
$LANG['log'][55]="Verbinding"; 
$LANG['log'][59]="Geautomatiseerde taak (CRON)"; 
$LANG['log'][60]="gebruikmaken van eenheid management voor dit item"; 
$LANG['log'][61]="Gebruiker aan instantie toevoegen"; 
$LANG['log'][62]="verwijder deze gebruiker compleet"; 
$LANG['log'][64]="aanpassing van een veld"; 
$LANG['log'][65]="regel"; 
$LANG['log'][66]="Beveiliging"; 
$LANG['log'][67]="wijziging van notitie"; 
$LANG['log'][70]="netwerk poort toegevoegen"; 
$LANG['log'][71]="meerdere netwerk poorten toegevoegd"; 
$LANG['log'][73]="netwerk poort verwijderd"; 
$LANG['log'][74]="meerdere netwerk poorten verwijderd"; 
$LANG['log'][75]="netwerk poort verplaatst"; 
$LANG['log'][77]="Netwerk poort toegevoegd aan een VLAN"; 
$LANG['log'][78]="Meerdere netwerk poorten samengevoegd tot VLAN"; 
$LANG['log'][79]="VLAN verwijderd van een netwerk poort"; 
$LANG['log'][80]="verwijder VLAN van meerdere netwerk poorten"; 
$LANG['log'][82]="Versie toegevoegd"; 
$LANG['log'][83]="wijziging van versie"; 
$LANG['log'][84]="verwijdering van een versie"; 
$LANG['log'][85]="Een licentie toegevoegd"; 
$LANG['log'][86]="wijziging van licentie"; 
$LANG['log'][87]="verwijderen van een licentie"; 
$LANG['log'][88]="Cartridges toegevoegd"; 
$LANG['log'][89]="Voeg verbruiksartikelen toe"; 
$LANG['log'][90]="uitsluiting van een inktpatroon"; 
$LANG['log'][91]="uitsluiting van verbruiksgoederen"; 
$LANG['log'][92]="herstel van een inktpatroon"; 
$LANG['log'][93]="teruggave van een verbruiksproduct"; 
$LANG['log'][94]="Inktpatronen update"; 
$LANG['log'][95]="Inktpatroon plaatsing"; 
$LANG['log'][96]="Inktpatroon verwijdering"; 
$LANG['log'][97]="verbruiksgoederen voor de gebruiker"; 
$LANG['log'][98]="een item toevoegen"; 
$LANG['log'][99]="aanpassing van een item"; 
$LANG['log'][100]="verwijderen van een item"; 

$LANG['login'][0]="Laatste ingelogd"; 
$LANG['login'][1]="Opnieuw inloggen"; 
$LANG['login'][2]="LDAP directory"; 
$LANG['login'][3]="IMAP/POP"; 
$LANG['login'][4]="CAS"; 
$LANG['login'][5]="Toegang geweigerd"; 
$LANG['login'][6]="Log-in"; 
$LANG['login'][7]="Wachtwoord"; 
$LANG['login'][8]="Login naam of wachtwoord niet ingevuld"; 
$LANG['login'][9]="Nog niet ge-authentificeerd"; 
$LANG['login'][10]="Authentificatie"; 
$LANG['login'][11]="Gebruiker heeft geen toelating voor verbinding in GLPI"; 
$LANG['login'][12]="Verkeerde gebruikersnaam of wachtwoord"; 
$LANG['login'][13]="Wachtwoord is leeg"; 
$LANG['login'][14]="onbekende gebruiker"; 
$LANG['login'][15]="Gebruiker niet gevonden of diverse gebruikers gevonden"; 
$LANG['login'][16]="mislukte authorisatie in LDAP"; 
$LANG['login'][18]="Standaard gebruik van GLPI"; 
$LANG['login'][20]="U heeft geen toegang tot deze applicatie, omdat uw account is verwijderd of gedeactiveerd."; 
$LANG['login'][21]="Test verbinding naar IMAP/POP server"; 
$LANG['login'][22]="Test geslaagd"; 
$LANG['login'][23]="Test mislukt"; 
$LANG['login'][24]="Laatste logindatum"; 
$LANG['login'][25]="U heeft de rechten niet om te verbinden"; 
$LANG['login'][26]="U moet JavaScript activeren in uw browser"; 
$LANG['login'][27]="U moet cookies accepteren om dit programma te bereiken"; 
$LANG['login'][30]="Verandering van de Authentificatie methode"; 
$LANG['login'][31]="Authentificatie d.m.v. LDAP directory"; 
$LANG['login'][32]="Authentificatie d.m.v. GLPI databank"; 
$LANG['login'][33]="Authentificatie d.m.v. IMAP/POP server"; 

$LANG['mailgate'][0]="Mail Ontvanger"; 
$LANG['mailgate'][2]="Haal de E-mail tickets nu op"; 
$LANG['mailgate'][3]="Aantal beschikbare en ontvangen E-mail"; 
$LANG['mailgate'][4]="De 'mbstring' extensie is niet gevonden. waarschuwing voor gebruikte 'charsets'."; 
$LANG['mailgate'][5]="Ongeldige bestand bijgevoegd"; 
$LANG['mailgate'][6]="Bestands bijlage is te groot"; 
$LANG['mailgate'][7]="Mail ontvanger: Maximale grootte van elk ingevoerd bestand (0: geen import)"; 
$LANG['mailgate'][9]="Uw email kon niet worden verwerkt.\n Indien het probleem blijft bestaan, contacteer de administrator"; 
$LANG['mailgate'][10]="Email geweigerd"; 
$LANG['mailgate'][11]="Emails importeren"; 
$LANG['mailgate'][12]="Onmogelijk om de email toe te wijzen aan een entiteit"; 
$LANG['mailgate'][13]="Reden van weigering"; 
$LANG['mailgate'][14]="Email niet gevonden, import onmogelijk"; 
$LANG['mailgate'][16]="Re:"; 

$LANG['mailing'][0]="-----------------------"; 
$LANG['mailing'][1]="======================================="; 
$LANG['mailing'][4]="Tussenkomst(en) reeds afgerond"; 
$LANG['mailing'][5]="Beschrijving van de tussenkomst"; 
$LANG['mailing'][10]="Opvolging van nieuwe tussenkomst"; 
$LANG['mailing'][12]="Ticket toekennen aan"; 
$LANG['mailing'][14]="Wijziging van de categorie van de tussenkomst"; 
$LANG['mailing'][15]="Wijziging van de prioriteit van de tussenkomst"; 
$LANG['mailing'][17]="Hardwareveranderingen van de tussenkomst"; 
$LANG['mailing'][18]="Wijzigen van de auteur van de tussenkomst"; 
$LANG['mailing'][19]="Nieuwe reservatie"; 
$LANG['mailing'][20]="Bijwerken groep van de tussenkomst"; 
$LANG['mailing'][21]="Verandering in ticket bron"; 
$LANG['mailing'][23]="Aanpassing in de boeking"; 
$LANG['mailing'][26]="Toegevoegde dokument:"; 
$LANG['mailing'][27]="Bijwerken van de status van het ticket"; 
$LANG['mailing'][29]="Boeking geannuleerd"; 
$LANG['mailing'][30]="Bijwerking van het ticket"; 
$LANG['mailing'][31]="Dit is een test E-mail om te controlleren of het mail-lijst systeem werkt"; 
$LANG['mailing'][32]="E-mail Test"; 
$LANG['mailing'][33]="Inktpatronen Alarm"; 
$LANG['mailing'][35]="Alarm, drempelwaarde bereikt voor het type verbruiksartikel:"; 
$LANG['mailing'][36]="Verbruiksartikelen Alarm"; 
$LANG['mailing'][37]="Contract geopend tijdens berichttijd"; 
$LANG['mailing'][39]="Contracten Alarm"; 
$LANG['mailing'][40]="Items aan het eind van de garantie termijn"; 
$LANG['mailing'][41]="Financieële Informatie Alarm"; 
$LANG['mailing'][42]="Verandering in de kosten per uur"; 
$LANG['mailing'][43]="Verandering in de vaste kosten"; 
$LANG['mailing'][44]="Verandering in de materiaal kosten"; 
$LANG['mailing'][45]="Verandering van de ticket titel"; 
$LANG['mailing'][46]="Verandering in ticket omschrijving"; 
$LANG['mailing'][47]="Fout in het versturen van de E-mail"; 
$LANG['mailing'][48]="Verandering in openings datum"; 
$LANG['mailing'][49]="Verandering in sluitings datum"; 
$LANG['mailing'][50]="Verander ticket ontvanger"; 
$LANG['mailing'][51]="Verlopen licenties :"; 
$LANG['mailing'][53]="Verandering van de oplossing"; 
$LANG['mailing'][54]="Vervaldatum"; 
$LANG['mailing'][100]="Categorie niet bepaald"; 
$LANG['mailing'][101]="Opvolging via E-mail AAN"; 
$LANG['mailing'][102]="Opvolging via E-mail UIT"; 
$LANG['mailing'][104]="Duur van de opvolging"; 
$LANG['mailing'][105]="Niet toegekend"; 
$LANG['mailing'][107]="Niets"; 
$LANG['mailing'][109]="Geen groep"; 
$LANG['mailing'][110]="Verkeerde E-mail"; 
$LANG['mailing'][113]="Kennisgeving model"; 
$LANG['mailing'][114]="Body"; 
$LANG['mailing'][115]="Email body"; 
$LANG['mailing'][116]="HTML"; 
$LANG['mailing'][117]="tekst"; 
$LANG['mailing'][118]="Email"; 
$LANG['mailing'][119]="Gebeurtenis"; 
$LANG['mailing'][120]="Meldingsmethode"; 
$LANG['mailing'][121]="Ontvangers"; 
$LANG['mailing'][122]="Reeds uitgevoerde taken"; 
$LANG['mailing'][123]="Ogelost Incident-ticket"; 
$LANG['mailing'][124]="Nieuwe vertaling toevoegen"; 
$LANG['mailing'][125]="Vertaling per default"; 
$LANG['mailing'][126]="Vertaling van het model"; 
$LANG['mailing'][127]="Sluiten van een Incident-ticket"; 
$LANG['mailing'][128]="laat het veld leeg voor HTML generatie"; 
$LANG['mailing'][129]="Incident-ticket verwijderen"; 
$LANG['mailing'][130]="Verzender"; 
$LANG['mailing'][131]="Ontvanger"; 
$LANG['mailing'][132]="Email hoofding"; 
$LANG['mailing'][133]="Email(s) verwijderen"; 
$LANG['mailing'][134]="Update opvolging"; 
$LANG['mailing'][135]="Opvolging stoppen"; 
$LANG['mailing'][136]="Reservatie vervalt"; 
$LANG['mailing'][137]="Gebruik van het materiaal"; 
$LANG['mailing'][138]="Lijst van beschikbare tags"; 
$LANG['mailing'][139]="Label"; 
$LANG['mailing'][140]="Label"; 
$LANG['mailing'][141]="Opvolging"; 
$LANG['mailing'][142]="Taken"; 
$LANG['mailing'][143]="Goedkeuring"; 
$LANG['mailing'][144]="Historiek"; 
$LANG['mailing'][145]="Waardenlijst"; 
$LANG['mailing'][146]="Enige waarde"; 
$LANG['mailing'][147]="Mogelijke waarde(n)"; 

$LANG['Menu'][0]="Computers"; 
$LANG['Menu'][1]="Netwerken"; 
$LANG['Menu'][2]="Printers"; 
$LANG['Menu'][3]="Beeldschermen"; 
$LANG['Menu'][4]="Software"; 
$LANG['Menu'][5]="Incident-Tickets"; 
$LANG['Menu'][6]="Verslagen"; 
$LANG['Menu'][11]="Instellingen"; 
$LANG['Menu'][12]="Onderhoud"; 
$LANG['Menu'][13]="Statistieken"; 
$LANG['Menu'][14]="Gebruikers"; 
$LANG['Menu'][15]="Administratie"; 
$LANG['Menu'][16]="Apparaten"; 
$LANG['Menu'][17]="Reserveringen"; 
$LANG['Menu'][18]="Middelen"; 
$LANG['Menu'][19]="Kennisdatabank"; 
$LANG['Menu'][20]="FAQ"; 
$LANG['Menu'][21]="Inktpatronen"; 
$LANG['Menu'][22]="Contactpersonen"; 
$LANG['Menu'][23]="Leveranciers"; 
$LANG['Menu'][24]="Commerciële info"; 
$LANG['Menu'][25]="Contracten"; 
$LANG['Menu'][26]="Beheer"; 
$LANG['Menu'][27]="Documenten"; 
$LANG['Menu'][28]="Status"; 
$LANG['Menu'][29]="Planning"; 
$LANG['Menu'][30]="Logs"; 
$LANG['Menu'][31]="Vereenvoudigde weergave"; 
$LANG['Menu'][32]="Verbruiksartikelen"; 
$LANG['Menu'][33]="OCSNG"; 
$LANG['Menu'][34]="Telefoons"; 
$LANG['Menu'][35]="Profielen"; 
$LANG['Menu'][36]="Groepen"; 
$LANG['Menu'][37]="Instantie's"; 
$LANG['Menu'][38]="Inventaris"; 
$LANG['Menu'][39]="E-mail Ontvangers"; 
$LANG['Menu'][40]="Bladwijzers"; 
$LANG['Menu'][41]="Rechten"; 

$LANG['monitors'][14]="Microfoon"; 
$LANG['monitors'][15]="Luidsprekers"; 
$LANG['monitors'][18]="Opties"; 
$LANG['monitors'][19]="Sub-D"; 
$LANG['monitors'][20]="BNC"; 
$LANG['monitors'][21]="Diameter"; 
$LANG['monitors'][32]="DVI"; 
$LANG['monitors'][33]="Pivot"; 

$LANG['networking'][4]="Netwerk poort"; 
$LANG['networking'][5]="RAM (MB)"; 
$LANG['networking'][6]="Netwerk poort"; 
$LANG['networking'][13]="netwerkpoorten gevonden"; 
$LANG['networking'][14]="IP"; 
$LANG['networking'][15]="MAC"; 
$LANG['networking'][17]="Verbonden met"; 
$LANG['networking'][19]="Netwerkpoort toevoegen ..."; 
$LANG['networking'][21]="Poort nummer"; 
$LANG['networking'][25]="op"; 
$LANG['networking'][37]="Netwerkpoort(en) gevonden"; 
$LANG['networking'][44]="Poort"; 
$LANG['networking'][46]="Meerdere poorten toevoegen ..."; 
$LANG['networking'][47]="Van"; 
$LANG['networking'][48]="Naar"; 
$LANG['networking'][51]="Netwerkpunt"; 
$LANG['networking'][55]="Associeer een VLAN"; 
$LANG['networking'][56]="VLAN"; 
$LANG['networking'][57]="Kies een MAC-adres uit de lijst of vul het hieronder in."; 
$LANG['networking'][58]="Verwijder een VLAN"; 
$LANG['networking'][59]="Gateway"; 
$LANG['networking'][60]="Masker"; 
$LANG['networking'][61]="Subnet"; 

$LANG['ocsconfig'][1]="Gebruiker van de OCSNG-database"; 
$LANG['ocsconfig'][2]="OCS-database host"; 
$LANG['ocsconfig'][3]="Wachtwoord van de OCSNG-gebruiker"; 
$LANG['ocsconfig'][4]="Naam van de OCS-database"; 
$LANG['ocsconfig'][5]="Importopties"; 
$LANG['ocsconfig'][6]="Negeer in de OCSNG import"; 
$LANG['ocsconfig'][7]="OCSNG database in UTF8"; 
$LANG['ocsconfig'][9]="Sluit de volgende tags uit (scheidingsteken $, nothing voor alles)"; 
$LANG['ocsconfig'][10]="Allesomvattende import"; 
$LANG['ocsconfig'][11]="Geen import"; 
$LANG['ocsconfig'][12]="Unit importation"; 
$LANG['ocsconfig'][13]="Unit importation: alles is geïmporteerd in de oorspronkelijke vorm"; 
$LANG['ocsconfig'][14]="Allesomvattende import: alles is geïmporteerd, maar het materiaal werd allesomvattend beheerd"; 
$LANG['ocsconfig'][15]="Geen import: de plug-in zal deze onderdelen niet importeren"; 
$LANG['ocsconfig'][16]="Default status"; 
$LANG['ocsconfig'][17]="Beperk het importeren tot de volgende extensies (separator $, niets indien alle)"; 
$LANG['ocsconfig'][18]="Controleer eerst of doublures beheerd worden door OCSNG"; 
$LANG['ocsconfig'][19]="Eenheid import op serienummer"; 
$LANG['ocsconfig'][27]="Algemene computerinformatie"; 
$LANG['ocsconfig'][36]="Modems"; 
$LANG['ocsconfig'][37]="Poorten"; 
$LANG['ocsconfig'][38]="Maak gebruik van de software dictionary in OCSNG"; 
$LANG['ocsconfig'][39]="OCSNG TAG"; 
$LANG['ocsconfig'][40]="Aantal computers die nog gesynchroniseerd moeten worden d.m.v OCSNG actie"; 
$LANG['ocsconfig'][41]="Register"; 
$LANG['ocsconfig'][43]="OCSNG Administratieve Informatie"; 
$LANG['ocsconfig'][48]="Gedrag tijdens afkoppelen"; 
$LANG['ocsconfig'][49]="Vuilnis"; 
$LANG['ocsconfig'][50]="Verwijdering"; 
$LANG['ocsconfig'][52]="Automatische aansluiting van computers"; 
$LANG['ocsconfig'][53]="Activeer de automatische verbinding"; 
$LANG['ocsconfig'][54]="Bestaande criteria van een computer"; 
$LANG['ocsconfig'][55]="Computers zoeken die deze status hebben"; 
$LANG['ocsconfig'][56]="leeg"; 
$LANG['ocsconfig'][57]="gelijk aan"; 
$LANG['ocsconfig'][58]="De link verbindt automatisch een computer van GLPI samen met één van OCS. Deze optie wordt slechts gebruikt door scripts voor synchronisatie (niet geschikt voor handmatige invoer)."; 
$LANG['ocsconfig'][59]="URL van de OCSNG console"; 

$LANG['ocsng'][0]="OCS Inventory NG"; 
$LANG['ocsng'][1]="Synchronisatie van de reeds geïmporteerde computers"; 
$LANG['ocsng'][2]="Import of nieuwe computers"; 
$LANG['ocsng'][3]="Verwijder koppelingen tussen GLPI en OCS"; 
$LANG['ocsng'][4]="Nieuwe OCS-computers linken aan bestaande GLPI-computers"; 
$LANG['ocsng'][5]="Nieuwe computers importeren"; 
$LANG['ocsng'][6]="Automatische update"; 
$LANG['ocsng'][7]="Geïmporteerd uit OCSNG"; 
$LANG['ocsng'][8]="Import gelukt"; 
$LANG['ocsng'][9]="Geen nieuwe computer om te importeren"; 
$LANG['ocsng'][10]="Computers bijgewerkt in OCS"; 
$LANG['ocsng'][11]="Computers bijwerken"; 
$LANG['ocsng'][12]="Geen nieuwe computer om bij te werken"; 
$LANG['ocsng'][13]="Datum importeren in GLPI"; 
$LANG['ocsng'][14]="Datum laatste OCS bijwerking in GLPI"; 
$LANG['ocsng'][15]="Geen veld geblokkeerd"; 
$LANG['ocsng'][16]="Geblokkeerde velden"; 
$LANG['ocsng'][18]="Verbinding met de OCS-database gelukt"; 
$LANG['ocsng'][19]="Geldige OCSNG versie en configuratie"; 
$LANG['ocsng'][20]="Ongeldige OCSNG-versie: RC3 noodzakelijk"; 
$LANG['ocsng'][21]="Verbinding met de OCS NG-database mislukt"; 
$LANG['ocsng'][22]="Opgelet!  De geïmporteerde gegevens (zie uw configuratie) zullen de bestaande gegevens overschrijven"; 
$LANG['ocsng'][23]="Import niet mogelijk: de GLPI-computer is al verbonden met een onderdeel van OCSNG"; 
$LANG['ocsng'][24]="Forceer Synchronisatie"; 
$LANG['ocsng'][26]="Kies een OCS server"; 
$LANG['ocsng'][27]="Geen OCS server(s) gedefinieerd"; 
$LANG['ocsng'][29]="OCSNG server"; 
$LANG['ocsng'][30]="Beschikbare monitor(s)"; 
$LANG['ocsng'][32]="Afgesloten apparaat(en)"; 
$LANG['ocsng'][34]="Beschikbare printer(s)"; 
$LANG['ocsng'][36]="Bestemmings instantie"; 
$LANG['ocsng'][37]="Activeer het overzicht"; 
$LANG['ocsng'][38]="Uitschakelen 'preview'"; 
$LANG['ocsng'][40]="Controleer de regel ?"; 
$LANG['ocsng'][41]="Handmatige import mode"; 
$LANG['ocsng'][42]="Òngeldige OCSNG configuratie ('TRACE_DELETED' moet actief zijn)"; 
$LANG['ocsng'][43]="Toegang tot de OCS databank geweigerd (gebruiker moet schrijfrechten hebben voor hardware.CHECKSUM)"; 
$LANG['ocsng'][44]="Toegang geweigerd tot de OCS databank (gebruiker moet verwijderrechten hebben voor de tabel deleted_equiv)"; 
$LANG['ocsng'][45]="OCS ID"; 
$LANG['ocsng'][46]="Verwijderd uit OCSNG"; 
$LANG['ocsng'][47]="Gekoppeld met een OCS computer"; 
$LANG['ocsng'][48]="De OCSNG ID van de computer is veranderd"; 
$LANG['ocsng'][49]="Agent"; 
$LANG['ocsng'][50]="Beschikbare IP(s)"; 
$LANG['ocsng'][52]="Beschikbare software"; 
$LANG['ocsng'][54]="Software verwijderd door de OCSNG synchronisatie"; 
$LANG['ocsng'][55]="Geblokkeerde volume(s)"; 
$LANG['ocsng'][57]="OCS Interface"; 

$LANG['pager'][1]="naar"; 
$LANG['pager'][2]="van"; 
$LANG['pager'][3]="in"; 
$LANG['pager'][4]="Tonen"; 
$LANG['pager'][5]="items"; 

$LANG['peripherals'][18]="Merk"; 
$LANG['peripherals'][31]="Globaal beheer"; 
$LANG['peripherals'][32]="Beheer per unit"; 
$LANG['peripherals'][33]="Beheerstype"; 

$LANG['phones'][18]="Merk"; 
$LANG['phones'][36]="Stroomvoorziening"; 
$LANG['phones'][38]="Koptelefoons"; 
$LANG['phones'][39]="Luidspreker"; 
$LANG['phones'][40]="Aantal lijnen"; 

$LANG['planning'][0]="De gevraagde technicus heeft al een tussenkomst gepland voor dat tijdstip"; 
$LANG['planning'][1]="Fout bij de datum invoer. De begindatum is later dan de einddatum."; 
$LANG['planning'][5]="Dag"; 
$LANG['planning'][6]="Week"; 
$LANG['planning'][8]="Tussenkomst"; 
$LANG['planning'][9]="op"; 
$LANG['planning'][10]="Ical"; 
$LANG['planning'][11]="Webcal"; 
$LANG['planning'][12]="De planning downloaden in Ical-formaat"; 
$LANG['planning'][13]="Webcal:// Synchronization"; 
$LANG['planning'][14]="Maand"; 
$LANG['planning'][15]="Uw planning"; 
$LANG['planning'][16]="Informatie"; 
$LANG['planning'][17]="Nog te doen"; 
$LANG['planning'][18]="Klaar"; 

$LANG['plugins'][0]="Overzicht plugins"; 
$LANG['plugins'][2]="Geinstalleerd / niet geconfigureerd"; 
$LANG['plugins'][3]="Geinstalleerd / niet geactiveerd"; 
$LANG['plugins'][4]="Fout / bij verwijdering"; 
$LANG['plugins'][5]="Niet bestaande functie(s)"; 
$LANG['plugins'][6]="Updaten"; 
$LANG['plugins'][7]="Geen plugin geïnstalleerd"; 
$LANG['plugins'][8]="Bekijk de lijst van plugins"; 
$LANG['plugins'][9]="Auteurs"; 
$LANG['plugins'][10]="Plugin is niet compatible met deze versie van GLPI."; 

$LANG['printers'][14]="Seriële poort"; 
$LANG['printers'][15]="Parallelle poort"; 
$LANG['printers'][18]="Poorten"; 
$LANG['printers'][27]="USB-poort"; 
$LANG['printers'][28]="Ethernet"; 
$LANG['printers'][29]="Wifi"; 
$LANG['printers'][30]="Paginateller"; 
$LANG['printers'][31]="Afgedrukte pagina's"; 

$LANG['profiles'][0]="Globale rechten"; 
$LANG['profiles'][1]="Rechten voor Instantie's"; 
$LANG['profiles'][2]="Profiel interface"; 
$LANG['profiles'][4]="Voeg opvolgsacties toe aan de Incident-tickets van mijn groep(en)"; 
$LANG['profiles'][5]="Een ticket aanmaken"; 
$LANG['profiles'][6]="Een opvolgingsactie aan mijn Incident-tickets toevoegen"; 
$LANG['profiles'][7]="Laat alle tickets zien"; 
$LANG['profiles'][8]="Toon alle opvolgingsacties (zowel publieke en privé)"; 
$LANG['profiles'][9]="Toon alle publieke taken en opvolgingsacties"; 
$LANG['profiles'][10]="Lezen"; 
$LANG['profiles'][11]="Schrijf"; 
$LANG['profiles'][12]="Geen toegang"; 
$LANG['profiles'][13]="Standaardprofiel"; 
$LANG['profiles'][14]="Een ticket verwijderen"; 
$LANG['profiles'][15]="Voeg een opvolging toe aan alle tickets"; 
$LANG['profiles'][16]="Verantwoordelijke voor een ticket"; 
$LANG['profiles'][17]="Neem een ticket over"; 
$LANG['profiles'][18]="Bijwerken van tussenkomst"; 
$LANG['profiles'][19]="Een ticket toewijzen"; 
$LANG['profiles'][20]="Bekijk de eigen planning"; 
$LANG['profiles'][21]="Toon de gehele planning"; 
$LANG['profiles'][22]="Profiel"; 
$LANG['profiles'][23]="Administratie van de materiaalreserveringen"; 
$LANG['profiles'][24]="Wachtwoord aanpassen"; 
$LANG['profiles'][26]="Laat alle tussenkomsten zien van Mijn groep"; 
$LANG['profiles'][27]="Toon de hardware van de groep of verbonden groep(en)"; 
$LANG['profiles'][28]="Recursief"; 
$LANG['profiles'][29]="Dynamisch"; 
$LANG['profiles'][30]="Bekijk OCSNG informatie"; 
$LANG['profiles'][31]="Handmatige synchronisatie met OCSNG"; 
$LANG['profiles'][32]="Bekijk toegewezen tickets (persoonlijk + groep associatie)"; 
$LANG['profiles'][33]="Geen gebruiker om te beginnen"; 
$LANG['profiles'][34]="Legenda"; 
$LANG['profiles'][35]="Bijwerken alle opvolgingen"; 
$LANG['profiles'][36]="Bekijk de agenda van leden van mijn groepen"; 
$LANG['profiles'][37]="Standaard entiteit"; 
$LANG['profiles'][38]="Zichtbaarheid"; 
$LANG['profiles'][39]="Toewijzing"; 
$LANG['profiles'][40]="Update"; 
$LANG['profiles'][41]="Creatie"; 
$LANG['profiles'][42]="Associatie"; 
$LANG['profiles'][43]="Methode van authenticatie en synchronisatie voor gebruikers"; 
$LANG['profiles'][44]="Wijzig de prioriteit"; 
$LANG['profiles'][45]="Voeg een taak toe aan alle Incident-tickets"; 
$LANG['profiles'][46]="Wijzig alle taken"; 
$LANG['profiles'][47]="Gebruiker toegevoegd vanaf een externe bron"; 
$LANG['profiles'][48]="Maak een validatieverzoek aan"; 
$LANG['profiles'][49]="Valideer alle Incident-tickets"; 

$LANG['registry'][1]="Register Hive"; 
$LANG['registry'][2]="Pad"; 
$LANG['registry'][3]="Sleutel/waarde"; 
$LANG['registry'][4]="Register sleutel(s) gevonden"; 
$LANG['registry'][5]="Geen sleutel gevonden in register"; 
$LANG['registry'][6]="OCSNG naam"; 

$LANG['reminder'][0]="Persoonlijke notities"; 
$LANG['reminder'][1]="Publieke notes"; 
$LANG['reminder'][6]="Nieuwe notitie"; 
$LANG['reminder'][9]="Tekst"; 
$LANG['reminder'][12]="Aan planning toevoegen"; 
$LANG['reminder'][15]="Zonder Titel"; 
$LANG['reminder'][16]="Globale aantekeningen"; 

$LANG['reports'][0]="Selecteer een te genereren verslag"; 
$LANG['reports'][4]="Lijst van hardware onder contract"; 
$LANG['reports'][11]="Hardware onder contract"; 
$LANG['reports'][12]="Hardwaretype"; 
$LANG['reports'][13]="Datum(s)"; 
$LANG['reports'][15]="Toon verslag"; 
$LANG['reports'][19]="Alternatieve naam"; 
$LANG['reports'][26]="Standaardverslag"; 
$LANG['reports'][27]="Op contract"; 
$LANG['reports'][28]="Op jaar"; 
$LANG['reports'][33]="Netwerk verslag"; 
$LANG['reports'][36]="Verbonden apparaten"; 
$LANG['reports'][37]="Netwerkpunt"; 
$LANG['reports'][38]="IP"; 
$LANG['reports'][39]="Op locatie"; 
$LANG['reports'][41]="Per hardware"; 
$LANG['reports'][42]="Op netwerkpunt"; 
$LANG['reports'][46]="hardware poorten"; 
$LANG['reports'][47]="apparaatpoort"; 
$LANG['reports'][49]="Netwerkverslag per hardwareunit"; 
$LANG['reports'][51]="Netwerkverslag op netwerkpunt"; 
$LANG['reports'][52]="switch"; 
$LANG['reports'][54]="Netwerkverslag op locatie"; 
$LANG['reports'][57]="Materiaallijst"; 
$LANG['reports'][58]="Verslag materiaal, per jaar"; 
$LANG['reports'][60]="Begindatum"; 
$LANG['reports'][61]="Afsluitdatum"; 
$LANG['reports'][62]="Financiële informatie over de hardware"; 
$LANG['reports'][63]="Andere commerciële info (licenties,inktpatronen,verbruiksartikelen)"; 
$LANG['reports'][64]="Datum van de oplossing"; 

$LANG['reservation'][1]="Items die geboekt kunnen worden"; 
$LANG['reservation'][2]="Apparaat tijdelijk niet beschikbaar"; 
$LANG['reservation'][3]="Niet-beschikbaar maken"; 
$LANG['reservation'][5]="Beschikbaar maken"; 
$LANG['reservation'][6]="Verbied reserveringen"; 
$LANG['reservation'][7]="Keur de reservering goed"; 
$LANG['reservation'][8]="Boek"; 
$LANG['reservation'][9]="Boek een item"; 
$LANG['reservation'][16]="naar"; 
$LANG['reservation'][17]="van"; 
$LANG['reservation'][18]="Het benodigde item is al geboekt voor de gevraagde datum"; 
$LANG['reservation'][20]="Terug naar de planning"; 
$LANG['reservation'][21]="Toon de planning"; 
$LANG['reservation'][22]="Wijzig de commentaar"; 
$LANG['reservation'][25]="Alle te reserveren materiaal"; 
$LANG['reservation'][27]="Toetsing"; 
$LANG['reservation'][28]="op week"; 
$LANG['reservation'][29]="op dag"; 
$LANG['reservation'][30]="keer"; 
$LANG['reservation'][31]="op"; 
$LANG['reservation'][35]="Lopende en toekomstige reserveringen"; 
$LANG['reservation'][36]="Voorbije reserveringen"; 
$LANG['reservation'][37]="Geen reserveringen"; 
$LANG['reservation'][38]="Weet u zeker dat u dit niet reserveerbare item wilt teruggeven?"; 
$LANG['reservation'][39]="Dit zal alle reserveringen verwijderen die bezig zijn"; 
$LANG['reservation'][40]="Materiaal reservaties die vandaag vervallen"; 

$LANG['rulesengine'][0]="is"; 
$LANG['rulesengine'][1]="is not"; 
$LANG['rulesengine'][2]="bevat"; 
$LANG['rulesengine'][3]="bestaat niet"; 
$LANG['rulesengine'][4]="beginnend bij"; 
$LANG['rulesengine'][5]="voltooid door/tegen"; 
$LANG['rulesengine'][6]="Criterium"; 
$LANG['rulesengine'][7]="Acties"; 
$LANG['rulesengine'][8]="Regel management"; 
$LANG['rulesengine'][9]="logical operator"; 
$LANG['rulesengine'][10]="Klassement"; 
$LANG['rulesengine'][11]="Aktie type"; 
$LANG['rulesengine'][12]="Velden"; 
$LANG['rulesengine'][13]="Waarde"; 
$LANG['rulesengine'][14]="Conditie"; 
$LANG['rulesengine'][15]="Reden"; 
$LANG['rulesengine'][16]="Criterium"; 
$LANG['rulesengine'][17]="Regels"; 
$LANG['rulesengine'][18]="Regels die een computer toewijzen aam een entiteit"; 
$LANG['rulesengine'][19]="Regels voor Instantie & rechten toekenning"; 
$LANG['rulesengine'][20]="Regels toegepast"; 
$LANG['rulesengine'][21]="Regels van toepassing in sub-entiteiten"; 
$LANG['rulesengine'][22]="Toekennen"; 
$LANG['rulesengine'][23]="Lokale regels"; 
$LANG['rulesengine'][24]="Regel type"; 
$LANG['rulesengine'][25]="Naam van de computer"; 
$LANG['rulesengine'][26]="controle regulier expressie"; 
$LANG['rulesengine'][27]="De reguliere expressie komt niet overeen"; 
$LANG['rulesengine'][28]="Bedrijfsregels voor Incident-tickets"; 
$LANG['rulesengine'][29]="Lijst van regels"; 
$LANG['rulesengine'][30]="Actie"; 
$LANG['rulesengine'][33]="Drop-downs woordenboek"; 
$LANG['rulesengine'][35]="Software woordenboek"; 
$LANG['rulesengine'][36]="Fabrikant woordeboek"; 
$LANG['rulesengine'][37]="Regels van toekenning van een categorie aan software"; 
$LANG['rulesengine'][38]="Her-berekening"; 
$LANG['rulesengine'][40]="de categorie"; 
$LANG['rulesengine'][41]="Validatie"; 
$LANG['rulesengine'][42]="and"; 
$LANG['rulesengine'][43]="OR"; 
$LANG['rulesengine'][45]="Toekennen waarde van een reguliere expressie"; 
$LANG['rulesengine'][46]="Toewijzen: Apparatuur IP-adres"; 
$LANG['rulesengine'][47]="Toewijzen: Apparatuur naam + domein"; 
$LANG['rulesengine'][48]="Apparatuur toewijzen"; 
$LANG['rulesengine'][49]="Toewijzen: Apparatuur MAC-adres"; 
$LANG['rulesengine'][50]="Computer model woordenboek"; 
$LANG['rulesengine'][51]="Overzicht monitormodellen"; 
$LANG['rulesengine'][52]="Lijst van modellen telefoons"; 
$LANG['rulesengine'][53]="Lijst van modellen randapparatuur"; 
$LANG['rulesengine'][54]="Lijst van printer modellen"; 
$LANG['rulesengine'][55]="Woordenboek met netwerkmodellen"; 
$LANG['rulesengine'][56]="Modellen"; 
$LANG['rulesengine'][60]="Overzicht computertypes"; 
$LANG['rulesengine'][61]="Overzicht monitortypes"; 
$LANG['rulesengine'][62]="Telefoon type woordenboek"; 
$LANG['rulesengine'][63]="Lijst van types randapparatuur"; 
$LANG['rulesengine'][64]="Printer type woordenboek"; 
$LANG['rulesengine'][65]="Woordenboek met types netwerkapparaten"; 
$LANG['rulesengine'][66]="Typen"; 
$LANG['rulesengine'][67]="Operating systems dictionary"; 
$LANG['rulesengine'][68]="Lijst van service packs"; 
$LANG['rulesengine'][69]="Lijst van OS versies"; 
$LANG['rulesengine'][70]="Regels voor het toewijzen van een Incident-ticket ontvangen via email"; 
$LANG['rulesengine'][76]="Herhaal lijst"; 
$LANG['rulesengine'][77]="Woordenboeken"; 
$LANG['rulesengine'][78]="Versie"; 
$LANG['rulesengine'][79]="Voeg het resultaat van een reguliere expressie toe"; 
$LANG['rulesengine'][80]="Globaal woordenboek"; 
$LANG['rulesengine'][81]="Resultaat van de regel"; 
$LANG['rulesengine'][82]="Resultaten in detail"; 
$LANG['rulesengine'][83]="U kunt het resultaat van een reguliere expressie te beïnvloeden met behulp van de string #0"; 
$LANG['rulesengine'][84]="Test regels (rules engine)"; 
$LANG['rulesengine'][85]="Resultaat van een reguliere expressie"; 
$LANG['rulesengine'][86]="categorie van de verwijderde software (door de repository)"; 
$LANG['rulesengine'][87]="Software verwijderd door GLPI dictionary"; 
$LANG['rulesengine'][90]="Bezig met verwerken..."; 
$LANG['rulesengine'][91]="Taak beëindigd."; 
$LANG['rulesengine'][92]="Waarschuwing voor de Software wordt hernoemt op basis van de dictionary"; 
$LANG['rulesengine'][93]="Waarschuwing! Deze handeling verwijderd de software uit dit systeem.<br>Informeer de gebruikers van de software."; 
$LANG['rulesengine'][94]="FUSIE"; 
$LANG['rulesengine'][95]="Fabrikant keuze"; 
$LANG['rulesengine'][96]="Hernoemen gebaseerd op de producenten dictionary<br>  (----- = Alle)"; 
$LANG['rulesengine'][97]="Geen enkel element wordt getest"; 
$LANG['rulesengine'][100]="Informatie over de cache"; 
$LANG['rulesengine'][102]="Regel naam"; 
$LANG['rulesengine'][103]="Objecten in cache"; 
$LANG['rulesengine'][104]="Originele waarde"; 
$LANG['rulesengine'][105]="Aangepaste waarde"; 
$LANG['rulesengine'][106]="Niet veranderd"; 
$LANG['rulesengine'][107]="In-actief"; 
$LANG['rulesengine'][108]="origineel"; 
$LANG['rulesengine'][110]="Toewijzingen gebruikersrechten"; 
$LANG['rulesengine'][111]="Toewijzing entiteit(en)"; 
$LANG['rulesengine'][112]="Toewijzing rechten en entiteiten"; 
$LANG['rulesengine'][120]="De engine stopt op de eerst gecontroleerde regel."; 
$LANG['rulesengine'][121]="De engine behandeld alle regels."; 
$LANG['rulesengine'][122]="De engine geeft her resultaat van een regel door aan de daar opvolgende."; 
$LANG['rulesengine'][130]="Entiteit van LDAP"; 
$LANG['rulesengine'][131]="Entiteit van TAG"; 
$LANG['rulesengine'][132]="Negeer de import"; 
$LANG['rulesengine'][133]="Entiteit vanuit domein"; 
$LANG['rulesengine'][134]="Weiger email (geen antwoord via email)"; 
$LANG['rulesengine'][135]="Weiger email (met emailantwoord)"; 
$LANG['rulesengine'][138]="LDAP criteria"; 
$LANG['rulesengine'][140]="Criterium toevoegen"; 
$LANG['rulesengine'][142]="Lijst van niet geïmporteerde emails"; 
$LANG['rulesengine'][144]="Entiteit gebaseerd op gebruikersprofiel"; 
$LANG['rulesengine'][145]="user en een enkel profiel"; 
$LANG['rulesengine'][146]="User met profiel"; 
$LANG['rulesengine'][147]="User met een enkel profiel"; 
$LANG['rulesengine'][148]="Emaildomain bekend"; 
$LANG['rulesengine'][150]="De regels die verband houden met de entiteit werden gedesactiveerd"; 

$LANG['search'][0]="Zoeken op"; 
$LANG['search'][1]="voor alle"; 
$LANG['search'][2]="bevat"; 
$LANG['search'][4]="gesorteerd op"; 
$LANG['search'][8]="Begindatum"; 
$LANG['search'][9]="Einddatum"; 
$LANG['search'][10]="in"; 
$LANG['search'][11]="Geziene items"; 
$LANG['search'][12]="Kies een einddatum"; 
$LANG['search'][15]="Geen item gevonden"; 
$LANG['search'][16]="Ten minste"; 
$LANG['search'][17]="Een zoekcriterium toevoegen"; 
$LANG['search'][18]="Een zoekcriterium verwijderen"; 
$LANG['search'][19]="Een globaal zoekcriterium toevoegen"; 
$LANG['search'][20]="Een globaal zoekcriterium verwijderen"; 

$LANG['setup'][0]="Drop-downs"; 
$LANG['setup'][2]="Gebruiker toevoegen"; 
$LANG['setup'][3]="LDAP directory link"; 
$LANG['setup'][4]="Computertype"; 
$LANG['setup'][5]="Besturingssystemen"; 
$LANG['setup'][6]="Personalisatie"; 
$LANG['setup'][9]="Netwerkinterfaces"; 
$LANG['setup'][10]="Weergave manier van achter- en voornamen"; 
$LANG['setup'][14]="e-mail"; 
$LANG['setup'][18]="Aanmelden"; 
$LANG['setup'][19]="Wachtwoord"; 
$LANG['setup'][20]="Password bevestiging"; 
$LANG['setup'][21]="Fout ! de 2 passwords zijn niet identiek"; 
$LANG['setup'][35]="MHz"; 
$LANG['setup'][39]="Private opvolging per default"; 
$LANG['setup'][40]="Private taken per default"; 
$LANG['setup'][41]="Kies de taal"; 
$LANG['setup'][42]="Netwerk types"; 
$LANG['setup'][43]="Printertypes"; 
$LANG['setup'][44]="Schermtypes"; 
$LANG['setup'][45]="Kasttype"; 
$LANG['setup'][46]="Defaultwaarde"; 
$LANG['setup'][47]="Standaardformaat voor grafiek"; 
$LANG['setup'][48]="Defaultwaarden"; 
$LANG['setup'][62]="Selecteer de in te stellen categorie"; 
$LANG['setup'][63]="Opgelet: u staat op het punt een rubriek te verwijderen die gebruikt wordt voor één of meer items"; 
$LANG['setup'][64]="Als u het verwijderen bevestigt, zullen aan de items onder deze rubriek null-waarden worden toegekend"; 
$LANG['setup'][65]="U kunt ook alle items onder deze rubriek vervangen door een andere"; 
$LANG['setup'][67]="Externe authentificaties"; 
$LANG['setup'][69]="Toesteltypes"; 
$LANG['setup'][70]="Generieke instellingen"; 
$LANG['setup'][71]="Firmware"; 
$LANG['setup'][73]="Netwerkpunt"; 
$LANG['setup'][74]="U kunt deze locatie niet verwijderen, omdat die sublocaties had"; 
$LANG['setup'][75]="Als kind van"; 
$LANG['setup'][79]="Categorie van de tickets"; 
$LANG['setup'][80]="Derdepartijtype"; 
$LANG['setup'][81]="Documenten - rubriek"; 
$LANG['setup'][82]="Contacttype"; 
$LANG['setup'][83]="Staat van het item"; 
$LANG['setup'][84]="Inktpatroontype"; 
$LANG['setup'][85]="Contracttype"; 
$LANG['setup'][86]="RAM-type"; 
$LANG['setup'][87]="Categorien in de Knowledgebase (kennis databank)"; 
$LANG['setup'][88]="Netwerk"; 
$LANG['setup'][89]="Domein"; 
$LANG['setup'][90]="VLAN's"; 
$LANG['setup'][91]="Computermodel"; 
$LANG['setup'][92]="Verbruiksartikeltype"; 
$LANG['setup'][93]="Hardeschijf interfaces"; 
$LANG['setup'][94]="Schermmodellen"; 
$LANG['setup'][95]="Netwerk modellen"; 
$LANG['setup'][96]="Printermodellen"; 
$LANG['setup'][97]="Randapparaatmodellen"; 
$LANG['setup'][98]="Taken categorie"; 
$LANG['setup'][99]="Gebouwnummer"; 
$LANG['setup'][100]="Kamernummer"; 
$LANG['setup'][101]="Maximum aantal automatische acties (run by CLI)"; 
$LANG['setup'][102]="Logniveau"; 
$LANG['setup'][103]="1 - Kritisch (aanmeldingsfout)"; 
$LANG['setup'][104]="2- Hoog (niet gebruikt)"; 
$LANG['setup'][105]="3- Belangrijk (Geslaagde aanmeldingen log-ins)"; 
$LANG['setup'][106]="4- Notities (toevoegen, verwijderen, opvolgen)"; 
$LANG['setup'][107]="5 - Volledig (alles)"; 
$LANG['setup'][109]="Hoe lang worden de logs bijgehouden in de databank (in dagen, 0 voor oneindig)"; 
$LANG['setup'][110]="Toon de niet-aangestelde tussenkomsten bij het inloggen"; 
$LANG['setup'][111]="Maximum aantal zoek resultaten per pagina"; 
$LANG['setup'][112]="Max. aantal karakters voor elk onderdeel van de lijst"; 
$LANG['setup'][113]="Standaardtaal"; 
$LANG['setup'][114]="Voorrangskleuren"; 
$LANG['setup'][115]="Standaarddrempel voor inktpatronen en verbruiksartikelen"; 
$LANG['setup'][116]="Wijs de tussenkomsten automatisch toe aan de technicus van dienst"; 
$LANG['setup'][117]="Anoniem bekijken van de FAQ toelaten"; 
$LANG['setup'][118]="Tekst van de log-inpagina"; 
$LANG['setup'][119]="Voorstelling"; 
$LANG['setup'][120]="Dynamische voorstelling (Ajax) voor dropdown en tekstvelden"; 
$LANG['setup'][121]="Wildcard om de dropdowns volledig te tonen"; 
$LANG['setup'][122]="Maximum aantal getoonde items in de dropdowns"; 
$LANG['setup'][123]="Gebruik dynamische weergave (Ajax) niet als het aantal items minder is dan (0 = nooit)"; 
$LANG['setup'][124]="Voeg automatisch een gebruiker van een externe authentificatiebron toe"; 
$LANG['setup'][125]="... van een externe bron"; 
$LANG['setup'][126]="Voeg automatisch een gebruiker van een externe bron toe"; 
$LANG['setup'][127]="Automatisch aanvullen van tekstvelden (in dynamische weergave, Ajax)"; 
$LANG['setup'][128]="Datumformaat"; 
$LANG['setup'][129]="Toon GLPI-ID"; 
$LANG['setup'][130]="Aantal dagen dat activiteitenlogs worden opgeslagen"; 
$LANG['setup'][132]="Toon de volledige naam in de dropdowns"; 
$LANG['setup'][133]="Activeer OCSNG-modus"; 
$LANG['setup'][134]="OCSNG-modus"; 
$LANG['setup'][135]="Normaal"; 
$LANG['setup'][136]="Vertaling"; 
$LANG['setup'][137]="Debuggen"; 
$LANG['setup'][138]="GLPI gebruiken in modus"; 
$LANG['setup'][139]="Gewoon"; 
$LANG['setup'][140]="Types"; 
$LANG['setup'][145]="Os"; 
$LANG['setup'][147]="Dynamische weergave (Ajax)"; 
$LANG['setup'][148]="Stap voor de uren"; 
$LANG['setup'][149]="Aantal decimalen in bedragen"; 
$LANG['setup'][150]="Nummer formattering"; 
$LANG['setup'][154]="Basedn"; 
$LANG['setup'][155]="rootdn (voor niet-anonieme verbindingen)"; 
$LANG['setup'][156]="Wachtwoord (voor niet-anonieme middelen)"; 
$LANG['setup'][157]="De LDAP-uitbreiding, van uw PHP-parser is niet geïnstalleerd"; 
$LANG['setup'][158]="LDAP kan niet gebruikt worden als externe verbindingsbron"; 
$LANG['setup'][159]="Verbindingsfilter"; 
$LANG['setup'][162]="IMAP/POP-configuratie"; 
$LANG['setup'][164]="IMAP/POP-hostnaam (gebruikers-e-mail is dan: login@thishost)"; 
$LANG['setup'][165]="De PHP-parser is gecompileerd zonder de IMAP-functies"; 
$LANG['setup'][166]="de IMAP/POP kan niet gebruikt worden als externe verbindingsbron"; 
$LANG['setup'][167]="GLPI/LDAP-links"; 
$LANG['setup'][168]="Verbindingsopties"; 
$LANG['setup'][169]="E-mail folder (optioneel, gewoonlijk INBOX)"; 
$LANG['setup'][170]="Verbindingsparameter"; 
$LANG['setup'][171]="Poort (optioneel)"; 
$LANG['setup'][172]="LDAP-poort (standaard = 389)"; 
$LANG['setup'][174]="CAS-host"; 
$LANG['setup'][175]="Poort"; 
$LANG['setup'][176]="Bronmap (optioneel)"; 
$LANG['setup'][177]="CAS-configuratie"; 
$LANG['setup'][178]="De uitbreiding CURL of DOMXML van uw PHP-parser is niet geïnstalleerd"; 
$LANG['setup'][179]="CAS kan niet gebruikt worden als externe verbindingsbron"; 
$LANG['setup'][180]="Gebruik TLS"; 
$LANG['setup'][181]="De start-TLS van LDAP_bestaat niet"; 
$LANG['setup'][182]="URL om op terug te vallen bij uitloggen"; 
$LANG['setup'][185]="Logfiles in verschilende bestanden (SQL, mail, cron...)"; 
$LANG['setup'][186]="Tijd zone"; 
$LANG['setup'][190]="x509 certificaat"; 
$LANG['setup'][191]="mail attribuut voor x509"; 
$LANG['setup'][192]="Ingeschakeld"; 
$LANG['setup'][193]="Indentificatie variabele in het veld _SERVER"; 
$LANG['setup'][194]="Opvragen aanvullende informatie uit LDAP-directory"; 
$LANG['setup'][195]="Behoud status"; 
$LANG['setup'][196]="Wis de status"; 
$LANG['setup'][197]="Kopieer computer status"; 
$LANG['setup'][198]="Aanpassen status"; 
$LANG['setup'][199]="Verwijder het logindomein uit 'login@domein'"; 
$LANG['setup'][200]="Oneindig"; 
$LANG['setup'][201]="Configuratie van opvolging van alerts & emails"; 
$LANG['setup'][202]="Gebruik van opvolging via e-mail activeren"; 
$LANG['setup'][203]="Administrator E-mail"; 
$LANG['setup'][204]="E-mailhandtekening"; 
$LANG['setup'][205]="E-mail verzonden naar administrator"; 
$LANG['setup'][206]="Mislukt, om eem E-mail naar de administrator te sturen"; 
$LANG['setup'][207]="Administrator antwoord op E-mail (alleen als nodig is)"; 
$LANG['setup'][217]="De PHP E-mailfunctie is onbekend of niet actief in het systeem"; 
$LANG['setup'][218]="Het gebruik van SMTP is nodig voor E-mail"; 
$LANG['setup'][219]="Sta het aanmaken van anonieme tickets toe (helpdesk.receiver)"; 
$LANG['setup'][221]="Begin van het boekjaar (dag en maand)"; 
$LANG['setup'][223]="Limiet van de planningsschema's"; 
$LANG['setup'][227]="(Base) URL van de Applicatie"; 
$LANG['setup'][228]="Login-veld"; 
$LANG['setup'][229]="Stuur een test e-mail naar de administrator"; 
$LANG['setup'][231]="Gebruik een SMTP server om E-mails te sturen"; 
$LANG['setup'][232]="SMTP Host"; 
$LANG['setup'][234]="SMTP Login"; 
$LANG['setup'][235]="SMTP wachtwoord"; 
$LANG['setup'][236]="Vorig technicien heeft ticket onder zijn beheer"; 
$LANG['setup'][237]="Beheerder"; 
$LANG['setup'][239]="Technicus die deze ticket beheerd"; 
$LANG['setup'][240]="Notificatie Optie's"; 
$LANG['setup'][241]="Geen persoonlijke criteria. Maak persoonlijke parameters aan?"; 
$LANG['setup'][242]="Alarm(en) optie('s)"; 
$LANG['setup'][243]="Alarm op verbruiksartikel"; 
$LANG['setup'][244]="Alarm op inktpatroon"; 
$LANG['setup'][245]="Frequentie herinneringen (terugroepingen)"; 
$LANG['setup'][246]="Alarm bij contracten"; 
$LANG['setup'][247]="Alarm op de finaciële informatie"; 
$LANG['setup'][248]="Groep die deze ticket beheerd"; 
$LANG['setup'][249]="Aanvrager groep"; 
$LANG['setup'][250]="Voorstelling van een zoekopdracht via standaardwaarden"; 
$LANG['setup'][252]="Items kiezen die standaard zichtbaar zijn"; 
$LANG['setup'][253]="Filter voor zoeken in groepen"; 
$LANG['setup'][254]="Doorzoek type"; 
$LANG['setup'][255]="Groep attribuut die zijn gebruikers bevat"; 
$LANG['setup'][256]="bij gebruikers"; 
$LANG['setup'][257]="in de groepen"; 
$LANG['setup'][258]="Gebruikers & Groepen"; 
$LANG['setup'][259]="Behoort tot de groepen"; 
$LANG['setup'][260]="Gebruikers attribuut met daarin zijn/haar groep(en)"; 
$LANG['setup'][261]="Groep DN"; 
$LANG['setup'][262]="Gebruik DN bij zoeken"; 
$LANG['setup'][263]="Zoekfilter voor gebruikers"; 
$LANG['setup'][264]="Alarm op verlopen licenties"; 
$LANG['setup'][271]="Beperk monitor management"; 
$LANG['setup'][272]="Beperk apparaat management"; 
$LANG['setup'][273]="Beperk telefoon management"; 
$LANG['setup'][274]="om handmatig toe te voegen"; 
$LANG['setup'][275]="Beperk printer management"; 
$LANG['setup'][280]="Automatische bijwerking van de elememten die bij de computers horen"; 
$LANG['setup'][281]="Verbinding / bijwerking gedrag"; 
$LANG['setup'][282]="Gedrag bij ontkoppelen"; 
$LANG['setup'][283]="Kopieer"; 
$LANG['setup'][284]="Wis"; 
$LANG['setup'][285]="Niet copiëren"; 
$LANG['setup'][286]="Niet verwijderen"; 
$LANG['setup'][300]="Controleer of er een nieuwe versie beschikbaar is"; 
$LANG['setup'][301]="Een nieuwe versie is beschikbaar:"; 
$LANG['setup'][302]="Deze is beschikbaar vanaf de GLPI-website: <a href='http://glpi-project.org' target='_blank'>http://glpi-project.org</a>"; 
$LANG['setup'][303]="U hebt de recentst beschikbare versie"; 
$LANG['setup'][304]="Connectie mislukt. Indien u zich achter een proxyserver bevindt, gelieve deze dan te configureren."; 
$LANG['setup'][305]="Iedere dag"; 
$LANG['setup'][306]="Kijk of er een upgrade bestaat"; 
$LANG['setup'][307]="Nooit"; 
$LANG['setup'][308]="Elke week"; 
$LANG['setup'][309]="Elke maand"; 
$LANG['setup'][310]="Onmogelijk om verbinding te maken met site."; 
$LANG['setup'][311]="Mislukt, om met de proxy server verbinding te maken"; 
$LANG['setup'][312]="Geen gegevens beschikbaar op de website"; 
$LANG['setup'][313]="Opgelet er is geen defaultwaarde beschikbaar"; 
$LANG['setup'][350]="Link met de items voor het aanmaken van tickets"; 
$LANG['setup'][351]="Alle items"; 
$LANG['setup'][352]="Items die gekoppeld kunnen worden aan een ticket"; 
$LANG['setup'][360]="Automatische velden (gemarkeerd met een *)"; 
$LANG['setup'][400]="Configuratie Proxy"; 
$LANG['setup'][407]="Vereenvoudigede weergave help link"; 
$LANG['setup'][408]="Standaard interface  help link"; 
$LANG['setup'][409]="Standaard kop voor het toevoegen van een document aan een ticket"; 
$LANG['setup'][503]="Telefoonmodellen"; 
$LANG['setup'][504]="Telefoontypes"; 
$LANG['setup'][505]="Stroomvoorzieningstype voor telefoons"; 
$LANG['setup'][601]="LDAP waarde"; 
$LANG['setup'][602]="Verbinding met OCSNG database"; 
$LANG['setup'][603]="Een gebruiker toevoegen"; 
$LANG['setup'][604]="Associeer aan een groep"; 
$LANG['setup'][606]="Kan niet toevoegen. Deze gebruiker bestaat al."; 
$LANG['setup'][607]="Associeer met een profiel"; 
$LANG['setup'][608]="Standaard is de software toewijsbaar aan een Incident-ticket"; 
$LANG['setup'][609]="Toevoegen mislukt. De OCS server bestaat al."; 
$LANG['setup'][610]="Verplichte titel"; 
$LANG['setup'][611]="Verplichte inhoud"; 
$LANG['setup'][612]="Verplichte categorie"; 
$LANG['setup'][613]="Voeg een gebruiker toe vanuit een LDAP-directory zonder machtiging"; 
$LANG['setup'][614]="Fout bij het bijwerken van 'login'. Deze gebruiker bestaat reeds."; 
$LANG['setup'][615]="Incident-ticket life cycle"; 
$LANG['setup'][616]="Van \ naar"; 
$LANG['setup'][620]="Link"; 
$LANG['setup'][621]="Zoekfilter voor entiteiten"; 
$LANG['setup'][622]="Attribuut dat een entiteit vertegenwoordigd"; 
$LANG['setup'][623]="Importeer entiteiten uit een LDAP-directory"; 
$LANG['setup'][650]="PHP"; 
$LANG['setup'][651]="SMTP"; 
$LANG['setup'][652]="SMTP+SSL"; 
$LANG['setup'][653]="SMTP+TLS"; 
$LANG['setup'][660]="Mail server"; 
$LANG['setup'][661]="Configuratie van meldingen is onmogelijk : maak hieronder gebruik van opvolging via e-mail"; 
$LANG['setup'][703]="Algemeen"; 
$LANG['setup'][704]="Notificatie's"; 
$LANG['setup'][707]="Waarschuwingen over reservaties"; 
$LANG['setup'][708]="Waarschuwingen voor niet gesloten Incident-tickets sinds"; 
$LANG['setup'][720]="Systeem informatie"; 
$LANG['setup'][721]="Informatie installatie en configuratie van het systeem"; 
$LANG['setup'][722]="Copiëren en plakken in een Incident-Ticket"; 
$LANG['setup'][731]="Waarde van de globale configuratie"; 
$LANG['setup'][732]="Domein emailservice"; 
$LANG['setup'][800]="MySQL repliceren"; 
$LANG['setup'][801]="Replica MySQL inschakelen"; 
$LANG['setup'][802]="Database"; 
$LANG['setup'][803]="Verschil tussen master en slave"; 
$LANG['setup'][806]="Maximale desynchonisatieverschil tussen master en slave (in minuten)"; 
$LANG['setup'][807]="De slave-database is gedesynchroniseerd, het verschil is"; 
$LANG['setup'][808]="'Slaaf' database niet in sync!"; 
$LANG['setup'][809]="MySQL replica: alleen lezen"; 
$LANG['setup'][810]="MySQL replicatie gedesynchroniseerd"; 

$LANG['software'][1]="Gekochte versie"; 
$LANG['software'][2]="Gebruik versie"; 
$LANG['software'][3]="Toegewezen licenties : niet-geïnstalleerd"; 
$LANG['software'][4]="Ongelimiteerd"; 
$LANG['software'][5]="Versies"; 
$LANG['software'][6]="Uitgever"; 
$LANG['software'][7]="Een versie toevoegen"; 
$LANG['software'][8]="Licentie toevoegen"; 
$LANG['software'][11]="Licenties"; 
$LANG['software'][17]="Geïnstalleerde software"; 
$LANG['software'][19]="Installaties (geïnstalleerde software)"; 
$LANG['software'][20]="Blijvend"; 
$LANG['software'][28]="OEM"; 
$LANG['software'][29]="Update"; 
$LANG['software'][30]="Type licenties"; 
$LANG['software'][32]="Vervallen"; 
$LANG['software'][44]="Installatie software"; 
$LANG['software'][45]="De-installeer software"; 
$LANG['software'][46]="Bruikbaar in Incident-tickets"; 
$LANG['software'][47]="Samenvoegen"; 
$LANG['software'][48]="Samenvoegen"; 
$LANG['software'][49]="Software verwijderd na samenvoeging"; 
$LANG['software'][50]="Toegekend aan een (bepaalde) computer"; 
$LANG['software'][51]="Er moet er minstens 1 zijn om te kunnen toewijzen"; 

$LANG['softwarecategories'][2]="Software zonder categorie"; 
$LANG['softwarecategories'][3]="Lijst van de software zonder categorie"; 
$LANG['softwarecategories'][4]="Lijst van alle software van een categorie"; 
$LANG['softwarecategories'][5]="Software categoriën"; 

$LANG['state'][0]="Status"; 
$LANG['state'][6]="Itemtype"; 
$LANG['state'][7]="Geen items gevonden"; 
$LANG['state'][11]="Samenvatting"; 

$LANG['stats'][0]="Selecteer statistieken die getoond moeten worden"; 
$LANG['stats'][1]="Globaal (algemeen)"; 
$LANG['stats'][2]="Er kan geen element worden getoond"; 
$LANG['stats'][3]="Per item"; 
$LANG['stats'][5]="Aantal Incident-tickets"; 
$LANG['stats'][6]="Gemiddelde duur voor oplossing"; 
$LANG['stats'][7]="Toon de grafieken"; 
$LANG['stats'][11]="Aantal opgeloste Incident-tickets"; 
$LANG['stats'][13]="Aantal Incident-tickets"; 
$LANG['stats'][15]="Gemiddelde duur voor oplossing"; 
$LANG['stats'][16]="Naam technicus"; 
$LANG['stats'][20]="Gebruikersnaam"; 
$LANG['stats'][23]="Geen statistieken beschikbaar"; 
$LANG['stats'][25]="Gemiddelde (echte) tijd van een Incident-ticket"; 
$LANG['stats'][27]="Totale echte tijd van een tussenkomst"; 
$LANG['stats'][30]="Gemiddelde vertraging voor tussenkomst bij een Incident-ticket"; 
$LANG['stats'][31]="Dag(en)"; 
$LANG['stats'][33]="Minuten"; 
$LANG['stats'][34]="Seconden"; 
$LANG['stats'][35]="Incident-tickets"; 
$LANG['stats'][44]="Naam Leverancier"; 
$LANG['stats'][45]="Per hardware"; 
$LANG['stats'][47]="Per Incident-ticket"; 
$LANG['stats'][48]="(toegewezen)"; 
$LANG['stats'][49]="(opvolging(en))"; 

$LANG['title'][5]="Kennis databank"; 
$LANG['title'][6]="Netwerk"; 
$LANG['title'][9]="Item status"; 
$LANG['title'][10]="Opvolging van een Incident-ticket"; 
$LANG['title'][13]="Gebruikersinformatie"; 
$LANG['title'][14]="Externe authentificatie bronnen"; 
$LANG['title'][24]="Assistentie"; 
$LANG['title'][26]="Hoofd"; 
$LANG['title'][27]="Verbindingen"; 
$LANG['title'][28]="Tussenkomsten"; 
$LANG['title'][30]="Componenten"; 
$LANG['title'][33]="Externe links"; 
$LANG['title'][34]="Links"; 
$LANG['title'][37]="Notities"; 
$LANG['title'][38]="Geschiedenis"; 
$LANG['title'][40]="Publieke and persoonlijke notities"; 
$LANG['title'][42]="Massa-aanpassingen"; 
$LANG['title'][43]="Register"; 

$LANG['tracking'][1]="Mijn apparaten"; 
$LANG['tracking'][2]="Of compleet zoeken"; 
$LANG['tracking'][3]="Verkeerde datum. Update afgebroken"; 
$LANG['tracking'][4]="Uw ticket heeft geen urgentie, wilt U dit verbeteren"; 
$LANG['tracking'][8]="Geen beschrijving voor uw ticket, probeer opnieuw"; 
$LANG['tracking'][9]="Defaultwaarden voor de Incident-tickets"; 
$LANG['tracking'][10]="Defaultwaarden voor de mail-ontvangers"; 
$LANG['tracking'][24]="Document Incident-ticket"; 
$LANG['tracking'][29]="Aantal"; 
$LANG['tracking'][30]="Nieuw"; 
$LANG['tracking'][31]="Bezig met verwerken (toegekend)"; 
$LANG['tracking'][32]="Bezig met verwerken (gepland)"; 
$LANG['tracking'][34]="Direct"; 
$LANG['tracking'][35]="Geschreven"; 
$LANG['tracking'][37]="Behoud de tickets als de hardware verwijderd wordt uit de inventaris lijst"; 
$LANG['tracking'][38]="Een e-mail was verzonden naar"; 
$LANG['tracking'][39]="Zichtbaar in de vereenvoudigde interface"; 

$LANG['transfer'][1]="Verzending"; 
$LANG['transfer'][3]="Indien ongebruikt"; 
$LANG['transfer'][4]="Maak de lijst leeg van onderdelen voor verzending"; 
$LANG['transfer'][5]="U kunt doorgaan om de onderdelen toe te voegen voor verzending of verstuur vanaf nu deze onderdelen"; 
$LANG['transfer'][6]="Mischien is het verstandig om eerst een backup te maken, voor u de items gaat versturen."; 
$LANG['transfer'][7]="Items te verzenden"; 
$LANG['transfer'][8]="Verzend mode"; 

$LANG['update'][88]="De versie van uw database is niet compatibel met de versie van de geïnstalleerde code. Een update is noodzakelijk."; 
$LANG['update'][89]="U probeert GLPI te gebruiken met een databaseversie bedoeld voor een hogere versie.  Gelieve de versie te installeren die met uw database overeenstemt."; 
$LANG['update'][90]="Fout tijdens het updaten van de databank"; 
$LANG['update'][91]="Opgelet!"; 
$LANG['update'][92]="U zult een Update van de GLPI-databank doen, genaamd:"; 
$LANG['update'][93]="Verbinding met databank gemaakt"; 
$LANG['update'][94]="Update gelukt, uw databank is up-to-date."; 
$LANG['update'][95]="Verbinding met de databank is mislukt, controleer / pas eventueel de connectieparameters aan in het bestand config_db.php"; 
$LANG['update'][96]="Nu hebben alle administrators 'super-admin'-rechten, dit gebruikerstype is nieuw toegevoegd."; 
$LANG['update'][105]="De update kan niet bereikt worden op deze manier!!"; 
$LANG['update'][106]="Ga terug naar GLPI"; 
$LANG['update'][107]="Ga nu verder met het updaten van de inhoud van de databank"; 
$LANG['update'][130]="Update van de locaties"; 
$LANG['update'][131]="De nieuwe structuur is hiërarchisch"; 
$LANG['update'][132]="Als u een scheidingsteken gebruikt, kunt u het instellen om het creëren van een nieuwe hiërarchie te automatiseren"; 
$LANG['update'][133]="U kunt ook een rootlocatie specificeren die alle gegenereerde locaties omvat"; 
$LANG['update'][134]="Scheidingsteken"; 
$LANG['update'][135]="Root locatie"; 
$LANG['update'][136]="Dit is de nieuwe hiërarchie. Indien OK, kunt u die valideren"; 
$LANG['update'][137]="Nieuwe hiërarchie"; 
$LANG['update'][138]="Huidige locaties"; 
$LANG['update'][139]="Optimalisatie van de tabellen"; 
$LANG['update'][140]="Indexen worden aangemaakt"; 
$LANG['update'][141]="Database schema gewijzigd"; 
$LANG['update'][142]="Data migratie"; 

$LANG['users'][1]="Titel"; 
$LANG['users'][2]="Categorie"; 

$LANG['validation'][0]="Validatie"; 
$LANG['validation'][1]="Aanvraag om validatie verzenden"; 
$LANG['validation'][2]="Status"; 
$LANG['validation'][3]="Datum aanvraag"; 
$LANG['validation'][4]="Datum validatie"; 
$LANG['validation'][5]="Commentaar bij de aanvraag"; 
$LANG['validation'][6]="Commentaar bij de validatie"; 
$LANG['validation'][7]="Validaties voor het Incident-ticket"; 
$LANG['validation'][9]="Wachtrij validatie"; 
$LANG['validation'][10]="Geweigerd"; 
$LANG['validation'][11]="Geaccepteerd"; 
$LANG['validation'][12]="Niet gevalideerd"; 
$LANG['validation'][13]="Aanvraag validatie verzonden naar"; 
$LANG['validation'][15]="Incident-ticket wacht op uw validatie"; 
$LANG['validation'][16]="Facultatief in het geval van acceptatie"; 
$LANG['validation'][18]="Aanvrager van de validatie"; 
$LANG['validation'][19]="Validatie geaccepteerd"; 
$LANG['validation'][20]="Validatie geweigerd"; 
$LANG['validation'][21]="Gevalideerd door"; 
$LANG['validation'][23]="De gekozen gebruiker heeft geen emailadres, de aanvraag werd gemaakt maar de bevstigingsemail kon niet worden verzonden"; 
$LANG['validation'][26]="Aanvraag validatie"; 
$LANG['validation'][27]="Een validatie aanvraag werd ingediend"; 
$LANG['validation'][28]="Status van de aanvraag voor validatie"; 
$LANG['validation'][29]="Bij weigering van een validatie moet u een reden opgeven"; 
$LANG['validation'][30]="Stopzetting van een aanvraag om validatie"; 
$LANG['validation'][31]="Update van de aanvraag om validatie"; 
$LANG['validation'][32]="De aanvraag tot validatie werd beantwoord"; 
$LANG['validation'][33]="Incident-tickets die op uw validatie wachten"; 
?>